
from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .atom_connection_field_extension_summary_expression import (
    AtomConnectionFieldExtensionSummaryExpression,
    AtomConnectionFieldExtensionSummaryExpressionGuard,
)
from .atom_connection_field_extension_summary_simple_expression import (
    AtomConnectionFieldExtensionSummarySimpleExpression,
)
from .atom_connection_field_extension_summary_grouping_expression import (
    AtomConnectionFieldExtensionSummaryGroupingExpression,
)


@JsonMap({})
class AtomConnectionFieldExtensionSummaryQueryConfigQueryFilter(BaseModel):
    """AtomConnectionFieldExtensionSummaryQueryConfigQueryFilter

    :param expression: expression
    :type expression: AtomConnectionFieldExtensionSummaryExpression
    """

    def __init__(
        self, expression: AtomConnectionFieldExtensionSummaryExpression, **kwargs
    ):
        """AtomConnectionFieldExtensionSummaryQueryConfigQueryFilter

        :param expression: expression
        :type expression: AtomConnectionFieldExtensionSummaryExpression
        """
        self.expression = (
            AtomConnectionFieldExtensionSummaryExpressionGuard.return_one_of(expression)
        )
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class AtomConnectionFieldExtensionSummaryQueryConfig(BaseModel):
    """AtomConnectionFieldExtensionSummaryQueryConfig

    :param query_filter: query_filter
    :type query_filter: AtomConnectionFieldExtensionSummaryQueryConfigQueryFilter
    """

    def __init__(
        self,
        query_filter: AtomConnectionFieldExtensionSummaryQueryConfigQueryFilter,
        **kwargs,
    ):
        """AtomConnectionFieldExtensionSummaryQueryConfig

        :param query_filter: query_filter
        :type query_filter: AtomConnectionFieldExtensionSummaryQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, AtomConnectionFieldExtensionSummaryQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"key_id": "keyId"})
class DocCacheKeyInput(BaseModel):
    """DocCacheKeyInput

    :param index: index, defaults to None
    :type index: int, optional
    :param key_id: key_id, defaults to None
    :type key_id: int, optional
    :param name: name, defaults to None
    :type name: str, optional
    """

    def __init__(
        self,
        index: int = SENTINEL,
        key_id: int = SENTINEL,
        name: str = SENTINEL,
        **kwargs
    ):
        """DocCacheKeyInput

        :param index: index, defaults to None
        :type index: int, optional
        :param key_id: key_id, defaults to None
        :type key_id: int, optional
        :param name: name, defaults to None
        :type name: str, optional
        """
        if index is not SENTINEL:
            self.index = index
        if key_id is not SENTINEL:
            self.key_id = key_id
        if name is not SENTINEL:
            self.name = name
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .property import Property


@JsonMap({"property": "Property", "id_": "id"})
class AtomStartupProperties(BaseModel):
    """AtomStartupProperties

    :param property: property, defaults to None
    :type property: List[Property], optional
    :param id_: A unique ID for the Runtime, Runtime cluster, or Runtime cloud. (This API is not applicable for runtimes attached to clouds)., defaults to None
    :type id_: str, optional
    """

    def __init__(
        self, property: List[Property] = SENTINEL, id_: str = SENTINEL, **kwargs
    ):
        """AtomStartupProperties

        :param property: property, defaults to None
        :type property: List[Property], optional
        :param id_: A unique ID for the Runtime, Runtime cluster, or Runtime cloud. (This API is not applicable for runtimes attached to clouds)., defaults to None
        :type id_: str, optional
        """
        if property is not SENTINEL:
            self.property = self._define_list(property, Property)
        if id_ is not SENTINEL:
            self.id_ = id_
        self._kwargs = kwargs




from typing import Union
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..net.transport.utils import parse_xml_to_dict
from ..models import (
    Process,
    ProcessBulkRequest,
    ProcessBulkResponse,
    ProcessQueryConfig,
    ProcessQueryResponse,
)


class ProcessService(BaseService):

    @cast_models
    def get_process(self, id_: str) -> Union[Process, str]:
        """Retrieves the properties of the process having the specified ID.

         The ordinary GET operation retrieves the properties of the process having the specified ID. The bulk GET operation retrieves the properties of the processes having the specified IDs, to a maximum of 100.

        :param id_: A unique ID assigned by the system to the process. For deployed processes and processes belonging to single-install integration packs, this value is the process component ID. For processes belonging to multi-install integration packs, this is an synthetic ID and does not match an actual process component. You can use this value as the `extensionGroupId` when querying the Environment Extensions object.
        :type id_: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[Process, str]
        """

        Validator(str).validate(id_)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Process/{{id}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("id", id_)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return Process._unmap(response)
        if content == "application/xml":
            return Process._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def bulk_process(
        self, request_body: ProcessBulkRequest = None
    ) -> Union[ProcessBulkResponse, str]:
        """To learn more about `bulk`, refer to [Bulk GET operations](#section/Introduction/Bulk-GET-operations).

        :param request_body: The request body., defaults to None
        :type request_body: ProcessBulkRequest, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[ProcessBulkResponse, str]
        """

        Validator(ProcessBulkRequest).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Process/bulk",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return ProcessBulkResponse._unmap(response)
        if content == "application/xml":
            return ProcessBulkResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_process(
        self, request_body: ProcessQueryConfig = None
    ) -> Union[ProcessQueryResponse, str]:
        """For general information about the structure of QUERY filters, their sample payloads, and how to handle the paged results, refer to [Query filters](#section/Introduction/Query-filters) and [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body., defaults to None
        :type request_body: ProcessQueryConfig, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[ProcessQueryResponse, str]
        """

        Validator(ProcessQueryConfig).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Process/query",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return ProcessQueryResponse._unmap(response)
        if content == "application/xml":
            return ProcessQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def query_more_process(self, request_body: str) -> Union[ProcessQueryResponse, str]:
        """To learn about using `queryMore`, refer to [Query paging](#section/Introduction/Query-paging).

        :param request_body: The request body.
        :type request_body: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[ProcessQueryResponse, str]
        """

        Validator(str).validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Process/queryMore",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body, "text/plain")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return ProcessQueryResponse._unmap(response)
        if content == "application/xml":
            return ProcessQueryResponse._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..list_queues import ListQueuesService
from ...models import ListQueuesAsyncResponse, AsyncOperationTokenResult


class ListQueuesServiceAsync(ListQueuesService):
    """
    Async Wrapper for ListQueuesServiceAsync
    """

    def async_token_list_queues(
        self, token: str
    ) -> Awaitable[Union[ListQueuesAsyncResponse, str]]:
        return to_async(super().async_token_list_queues)(token)

    def async_get_list_queues(
        self, id_: str
    ) -> Awaitable[Union[AsyncOperationTokenResult, str]]:
        return to_async(super().async_get_list_queues)(id_)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"days_of_month": "daysOfMonth", "days_of_week": "daysOfWeek"})
class Schedule(BaseModel):
    """Schedule

    :param days_of_month: 1 is the first day of the month and 31 is the last day of the month., defaults to None
    :type days_of_month: str, optional
    :param days_of_week: 1 is Sunday and 7 is Saturday., defaults to None
    :type days_of_week: str, optional
    :param hours: Uses a 24-hour clock. 0 is midnight and 12 is noon., defaults to None
    :type hours: str, optional
    :param minutes: 0 is the first minute of the hour — for example, 1:00 A.M.59 is the last minute of the hour — for example, 1:59 A.M., defaults to None
    :type minutes: str, optional
    :param months: 1 is January and 12 is December. In most cases this is set to an asterisk [*]., defaults to None
    :type months: str, optional
    :param years: The standard year format. In most cases this is set to an asterisk [*]., defaults to None
    :type years: str, optional
    """

    def __init__(
        self,
        days_of_month: str = SENTINEL,
        days_of_week: str = SENTINEL,
        hours: str = SENTINEL,
        minutes: str = SENTINEL,
        months: str = SENTINEL,
        years: str = SENTINEL,
        **kwargs
    ):
        """Schedule

        :param days_of_month: 1 is the first day of the month and 31 is the last day of the month., defaults to None
        :type days_of_month: str, optional
        :param days_of_week: 1 is Sunday and 7 is Saturday., defaults to None
        :type days_of_week: str, optional
        :param hours: Uses a 24-hour clock. 0 is midnight and 12 is noon., defaults to None
        :type hours: str, optional
        :param minutes: 0 is the first minute of the hour — for example, 1:00 A.M.59 is the last minute of the hour — for example, 1:59 A.M., defaults to None
        :type minutes: str, optional
        :param months: 1 is January and 12 is December. In most cases this is set to an asterisk [*]., defaults to None
        :type months: str, optional
        :param years: The standard year format. In most cases this is set to an asterisk [*]., defaults to None
        :type years: str, optional
        """
        if days_of_month is not SENTINEL:
            self.days_of_month = days_of_month
        if days_of_week is not SENTINEL:
            self.days_of_week = days_of_week
        if hours is not SENTINEL:
            self.hours = hours
        if minutes is not SENTINEL:
            self.minutes = minutes
        if months is not SENTINEL:
            self.months = months
        if years is not SENTINEL:
            self.years = years
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel


@JsonMap({})
class QueryFilter(BaseModel):
    """QueryFilter

    :param expression: expression
    :type expression: dict
    """

    def __init__(self, expression: dict, **kwargs):
        """QueryFilter

        :param expression: expression
        :type expression: dict
        """
        self.expression = expression
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..atom_startup_properties import AtomStartupPropertiesService
from ...models import (
    AtomStartupProperties,
    AtomStartupPropertiesBulkResponse,
    AtomStartupPropertiesBulkRequest,
)


class AtomStartupPropertiesServiceAsync(AtomStartupPropertiesService):
    """
    Async Wrapper for AtomStartupPropertiesServiceAsync
    """

    def get_atom_startup_properties(
        self, id_: str
    ) -> Awaitable[Union[AtomStartupProperties, str]]:
        return to_async(super().get_atom_startup_properties)(id_)

    def bulk_atom_startup_properties(
        self, request_body: AtomStartupPropertiesBulkRequest = None
    ) -> Awaitable[Union[AtomStartupPropertiesBulkResponse, str]]:
        return to_async(super().bulk_atom_startup_properties)(request_body)




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..runtime_release_schedule import RuntimeReleaseScheduleService
from ...models import (
    RuntimeReleaseSchedule,
    RuntimeReleaseScheduleBulkResponse,
    RuntimeReleaseScheduleBulkRequest,
)


class RuntimeReleaseScheduleServiceAsync(RuntimeReleaseScheduleService):
    """
    Async Wrapper for RuntimeReleaseScheduleServiceAsync
    """

    def create_runtime_release_schedule(
        self, request_body: RuntimeReleaseSchedule = None
    ) -> Awaitable[Union[RuntimeReleaseSchedule, str]]:
        return to_async(super().create_runtime_release_schedule)(request_body)

    def get_runtime_release_schedule(
        self, id_: str
    ) -> Awaitable[Union[RuntimeReleaseSchedule, str]]:
        return to_async(super().get_runtime_release_schedule)(id_)

    def update_runtime_release_schedule(
        self, id_: str, request_body: RuntimeReleaseSchedule = None
    ) -> Awaitable[Union[RuntimeReleaseSchedule, str]]:
        return to_async(super().update_runtime_release_schedule)(id_, request_body)

    def delete_runtime_release_schedule(self, id_: str) -> Awaitable[None]:
        return to_async(super().delete_runtime_release_schedule)(id_)

    def bulk_runtime_release_schedule(
        self, request_body: RuntimeReleaseScheduleBulkRequest = None
    ) -> Awaitable[Union[RuntimeReleaseScheduleBulkResponse, str]]:
        return to_async(super().bulk_runtime_release_schedule)(request_body)




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .account_group_user_role_expression import (
    AccountGroupUserRoleExpression,
    AccountGroupUserRoleExpressionGuard,
)
from .account_group_user_role_simple_expression import (
    AccountGroupUserRoleSimpleExpression,
)
from .account_group_user_role_grouping_expression import (
    AccountGroupUserRoleGroupingExpression,
)


@JsonMap({})
class AccountGroupUserRoleQueryConfigQueryFilter(BaseModel):
    """AccountGroupUserRoleQueryConfigQueryFilter

    :param expression: expression
    :type expression: AccountGroupUserRoleExpression
    """

    def __init__(self, expression: AccountGroupUserRoleExpression, **kwargs):
        """AccountGroupUserRoleQueryConfigQueryFilter

        :param expression: expression
        :type expression: AccountGroupUserRoleExpression
        """
        self.expression = AccountGroupUserRoleExpressionGuard.return_one_of(expression)
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class AccountGroupUserRoleQueryConfig(BaseModel):
    """AccountGroupUserRoleQueryConfig

    :param query_filter: query_filter
    :type query_filter: AccountGroupUserRoleQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: AccountGroupUserRoleQueryConfigQueryFilter, **kwargs
    ):
        """AccountGroupUserRoleQueryConfig

        :param query_filter: query_filter
        :type query_filter: AccountGroupUserRoleQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, AccountGroupUserRoleQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .as2_partner_info import As2PartnerInfo
from .as2_mdn_options import As2MdnOptions
from .as2_message_options import As2MessageOptions
from .as2_my_company_info import As2MyCompanyInfo


@JsonMap(
    {
        "as2_default_partner_info": "AS2DefaultPartnerInfo",
        "as2_default_partner_mdn_options": "AS2DefaultPartnerMDNOptions",
        "as2_default_partner_message_options": "AS2DefaultPartnerMessageOptions",
        "as2_my_company_info": "AS2MyCompanyInfo",
    }
)
class As2ReceiveOptions(BaseModel):
    """As2ReceiveOptions

    :param as2_default_partner_info: as2_default_partner_info, defaults to None
    :type as2_default_partner_info: As2PartnerInfo, optional
    :param as2_default_partner_mdn_options: as2_default_partner_mdn_options, defaults to None
    :type as2_default_partner_mdn_options: As2MdnOptions, optional
    :param as2_default_partner_message_options: as2_default_partner_message_options, defaults to None
    :type as2_default_partner_message_options: As2MessageOptions, optional
    :param as2_my_company_info: as2_my_company_info, defaults to None
    :type as2_my_company_info: As2MyCompanyInfo, optional
    """

    def __init__(
        self,
        as2_default_partner_info: As2PartnerInfo = SENTINEL,
        as2_default_partner_mdn_options: As2MdnOptions = SENTINEL,
        as2_default_partner_message_options: As2MessageOptions = SENTINEL,
        as2_my_company_info: As2MyCompanyInfo = SENTINEL,
        **kwargs,
    ):
        """As2ReceiveOptions

        :param as2_default_partner_info: as2_default_partner_info, defaults to None
        :type as2_default_partner_info: As2PartnerInfo, optional
        :param as2_default_partner_mdn_options: as2_default_partner_mdn_options, defaults to None
        :type as2_default_partner_mdn_options: As2MdnOptions, optional
        :param as2_default_partner_message_options: as2_default_partner_message_options, defaults to None
        :type as2_default_partner_message_options: As2MessageOptions, optional
        :param as2_my_company_info: as2_my_company_info, defaults to None
        :type as2_my_company_info: As2MyCompanyInfo, optional
        """
        if as2_default_partner_info is not SENTINEL:
            self.as2_default_partner_info = self._define_object(
                as2_default_partner_info, As2PartnerInfo
            )
        if as2_default_partner_mdn_options is not SENTINEL:
            self.as2_default_partner_mdn_options = self._define_object(
                as2_default_partner_mdn_options, As2MdnOptions
            )
        if as2_default_partner_message_options is not SENTINEL:
            self.as2_default_partner_message_options = self._define_object(
                as2_default_partner_message_options, As2MessageOptions
            )
        if as2_my_company_info is not SENTINEL:
            self.as2_my_company_info = self._define_object(
                as2_my_company_info, As2MyCompanyInfo
            )
        self._kwargs = kwargs




from .as2_connector_record_query_config import (
    As2ConnectorRecordQueryConfig,
    As2ConnectorRecordQueryConfigQueryFilter,
)
from .as2_connector_record_query_response import As2ConnectorRecordQueryResponse
from .account import Account, AccountStatus, SupportLevel
from .account_bulk_request import AccountBulkRequest, AccountBulkRequestType
from .account_bulk_response import AccountBulkResponse, AccountBulkResponseResponse
from .account_query_config import AccountQueryConfig, AccountQueryConfigQueryFilter
from .account_query_response import AccountQueryResponse
from .account_cloud_attachment_properties import (
    AccountCloudAttachmentProperties,
    As2Workload,
    FlowControlParallelProcessTypeOverride,
    HttpWorkload,
)
from .async_operation_token_result import AsyncOperationTokenResult
from .account_cloud_attachment_properties_async_response import (
    AccountCloudAttachmentPropertiesAsyncResponse,
)
from .account_cloud_attachment_quota import AccountCloudAttachmentQuota
from .account_cloud_attachment_quota_bulk_request import (
    AccountCloudAttachmentQuotaBulkRequest,
    AccountCloudAttachmentQuotaBulkRequestType,
)
from .account_cloud_attachment_quota_bulk_response import (
    AccountCloudAttachmentQuotaBulkResponse,
    AccountCloudAttachmentQuotaBulkResponseResponse,
)
from .account_group import AccountGroup, AutoSubscribeAlertLevel
from .account_group_bulk_request import (
    AccountGroupBulkRequest,
    AccountGroupBulkRequestType,
)
from .account_group_bulk_response import (
    AccountGroupBulkResponse,
    AccountGroupBulkResponseResponse,
)
from .account_group_query_config import (
    AccountGroupQueryConfig,
    AccountGroupQueryConfigQueryFilter,
)
from .account_group_query_response import AccountGroupQueryResponse
from .account_group_account import AccountGroupAccount
from .account_group_account_query_config import (
    AccountGroupAccountQueryConfig,
    AccountGroupAccountQueryConfigQueryFilter,
)
from .account_group_account_query_response import AccountGroupAccountQueryResponse
from .account_group_user_role import AccountGroupUserRole
from .account_group_user_role_query_config import (
    AccountGroupUserRoleQueryConfig,
    AccountGroupUserRoleQueryConfigQueryFilter,
)
from .account_group_user_role_query_response import AccountGroupUserRoleQueryResponse
from .account_sso_config import AccountSsoConfig
from .account_sso_config_bulk_request import (
    AccountSsoConfigBulkRequest,
    AccountSsoConfigBulkRequestType,
)
from .account_sso_config_bulk_response import (
    AccountSsoConfigBulkResponse,
    AccountSsoConfigBulkResponseResponse,
)
from .account_user_federation import AccountUserFederation
from .account_user_federation_query_config import (
    AccountUserFederationQueryConfig,
    AccountUserFederationQueryConfigQueryFilter,
)
from .account_user_federation_query_response import AccountUserFederationQueryResponse
from .account_user_role import AccountUserRole
from .account_user_role_query_config import (
    AccountUserRoleQueryConfig,
    AccountUserRoleQueryConfigQueryFilter,
)
from .account_user_role_query_response import AccountUserRoleQueryResponse
from .api_usage_count_query_config import (
    ApiUsageCountQueryConfig,
    ApiUsageCountQueryConfigQueryFilter,
)
from .api_usage_count_query_response import ApiUsageCountQueryResponse
from .atom import Atom, Capabilities, AtomStatus, AtomType
from .atom_bulk_request import AtomBulkRequest, AtomBulkRequestType
from .atom_bulk_response import AtomBulkResponse, AtomBulkResponseResponse
from .atom_query_config import AtomQueryConfig, AtomQueryConfigQueryFilter
from .atom_query_response import AtomQueryResponse
from .atom_counters_async_response import AtomCountersAsyncResponse
from .persisted_process_properties_async_response import (
    PersistedProcessPropertiesAsyncResponse,
)
from .atom_as2_artifacts import AtomAs2Artifacts
from .log_download import LogDownload
from .atom_connection_field_extension_summary_query_config import (
    AtomConnectionFieldExtensionSummaryQueryConfig,
    AtomConnectionFieldExtensionSummaryQueryConfigQueryFilter,
)
from .atom_connection_field_extension_summary_query_response import (
    AtomConnectionFieldExtensionSummaryQueryResponse,
)
from .atom_connector_versions import AtomConnectorVersions
from .atom_connector_versions_bulk_request import (
    AtomConnectorVersionsBulkRequest,
    AtomConnectorVersionsBulkRequestType,
)
from .atom_connector_versions_bulk_response import (
    AtomConnectorVersionsBulkResponse,
    AtomConnectorVersionsBulkResponseResponse,
)
from .atom_counters import AtomCounters
from .atom_log import AtomLog
from .atom_purge import AtomPurge
from .atom_security_policies import AtomSecurityPolicies
from .atom_security_policies_async_response import AtomSecurityPoliciesAsyncResponse
from .atom_startup_properties import AtomStartupProperties
from .atom_startup_properties_bulk_request import (
    AtomStartupPropertiesBulkRequest,
    AtomStartupPropertiesBulkRequestType,
)
from .atom_startup_properties_bulk_response import (
    AtomStartupPropertiesBulkResponse,
    AtomStartupPropertiesBulkResponseResponse,
)
from .atom_worker_log import AtomWorkerLog
from .audit_log import AuditLog
from .audit_log_bulk_request import AuditLogBulkRequest, AuditLogBulkRequestType
from .audit_log_bulk_response import AuditLogBulkResponse, AuditLogBulkResponseResponse
from .audit_log_query_config import AuditLogQueryConfig, AuditLogQueryConfigQueryFilter
from .audit_log_query_response import AuditLogQueryResponse
from .branch import Branch
from .branch_bulk_request import BranchBulkRequest, BranchBulkRequestType
from .branch_bulk_response import BranchBulkResponse, BranchBulkResponseResponse
from .branch_query_config import BranchQueryConfig, BranchQueryConfigQueryFilter
from .branch_query_response import BranchQueryResponse
from .change_listener_status_request import ChangeListenerStatusRequest, Action
from .clear_queue_request import ClearQueueRequest
from .cloud import Cloud
from .cloud_bulk_request import CloudBulkRequest, CloudBulkRequestType
from .cloud_bulk_response import CloudBulkResponse, CloudBulkResponseResponse
from .cloud_query_config import CloudQueryConfig, CloudQueryConfigQueryFilter
from .cloud_query_response import CloudQueryResponse
from .component import Component, ComponentType
from .component_bulk_request import ComponentBulkRequest, ComponentBulkRequestType
from .component_bulk_response import (
    ComponentBulkResponse,
    ComponentBulkResponseResponse,
)
from .component_atom_attachment import ComponentAtomAttachment
from .component_atom_attachment_query_config import (
    ComponentAtomAttachmentQueryConfig,
    ComponentAtomAttachmentQueryConfigQueryFilter,
)
from .component_atom_attachment_query_response import (
    ComponentAtomAttachmentQueryResponse,
)
from .component_diff_request import ComponentDiffRequest
from .component_diff_response_create import (
    ComponentDiffResponseCreate,
    ComponentDiffResponse,
)
from .component_diff_request_bulk_request import (
    ComponentDiffRequestBulkRequest,
    ComponentDiffRequestBulkRequestType,
)
from .component_diff_request_bulk_response import (
    ComponentDiffRequestBulkResponse,
    ComponentDiffRequestBulkResponseResponse,
)
from .component_environment_attachment import ComponentEnvironmentAttachment
from .component_environment_attachment_query_config import (
    ComponentEnvironmentAttachmentQueryConfig,
    ComponentEnvironmentAttachmentQueryConfigQueryFilter,
)
from .component_environment_attachment_query_response import (
    ComponentEnvironmentAttachmentQueryResponse,
)
from .component_metadata import ComponentMetadata, ComponentMetadataType
from .component_metadata_bulk_request import (
    ComponentMetadataBulkRequest,
    ComponentMetadataBulkRequestType,
)
from .component_metadata_bulk_response import (
    ComponentMetadataBulkResponse,
    ComponentMetadataBulkResponseResponse,
)
from .component_metadata_query_config import (
    ComponentMetadataQueryConfig,
    ComponentMetadataQueryConfigQueryFilter,
)
from .component_metadata_query_response import ComponentMetadataQueryResponse
from .component_reference import ComponentReference
from .component_reference_bulk_request import (
    ComponentReferenceBulkRequest,
    ComponentReferenceBulkRequestType,
)
from .component_reference_bulk_response import (
    ComponentReferenceBulkResponse,
    ComponentReferenceBulkResponseResponse,
)
from .component_reference_query_config import (
    ComponentReferenceQueryConfig,
    ComponentReferenceQueryConfigQueryFilter,
)
from .component_reference_query_response import ComponentReferenceQueryResponse
from .connection_licensing_report import ConnectionLicensingReport
from .connection_licensing_download import ConnectionLicensingDownload
from .connector import Connector
from .connector_bulk_request import ConnectorBulkRequest, ConnectorBulkRequestType
from .connector_bulk_response import (
    ConnectorBulkResponse,
    ConnectorBulkResponseResponse,
)
from .connector_query_config import (
    ConnectorQueryConfig,
    ConnectorQueryConfigQueryFilter,
)
from .connector_query_response import ConnectorQueryResponse
from .connector_document import ConnectorDocument
from .connector_document_download import ConnectorDocumentDownload
from .custom_tracked_field_query_config import (
    CustomTrackedFieldQueryConfig,
    CustomTrackedFieldQueryConfigQueryFilter,
)
from .custom_tracked_field_query_response import CustomTrackedFieldQueryResponse
from .deployed_expired_certificate_query_config import (
    DeployedExpiredCertificateQueryConfig,
    DeployedExpiredCertificateQueryConfigQueryFilter,
)
from .deployed_expired_certificate_query_response import (
    DeployedExpiredCertificateQueryResponse,
)
from .deployed_package import DeployedPackage, DeployedPackageListenerStatus
from .deployed_package_bulk_request import (
    DeployedPackageBulkRequest,
    DeployedPackageBulkRequestType,
)
from .deployed_package_bulk_response import (
    DeployedPackageBulkResponse,
    DeployedPackageBulkResponseResponse,
)
from .deployed_package_query_config import (
    DeployedPackageQueryConfig,
    DeployedPackageQueryConfigQueryFilter,
)
from .deployed_package_query_response import DeployedPackageQueryResponse
from .deployment import Deployment, DeploymentListenerStatus
from .deployment_bulk_request import DeploymentBulkRequest, DeploymentBulkRequestType
from .deployment_bulk_response import (
    DeploymentBulkResponse,
    DeploymentBulkResponseResponse,
)
from .deployment_query_config import (
    DeploymentQueryConfig,
    DeploymentQueryConfigQueryFilter,
)
from .deployment_query_response import DeploymentQueryResponse
from .process_environment_attachment_query_config import (
    ProcessEnvironmentAttachmentQueryConfig,
    ProcessEnvironmentAttachmentQueryConfigQueryFilter,
)
from .process_environment_attachment_query_response import (
    ProcessEnvironmentAttachmentQueryResponse,
)
from .document_count_account_query_config import (
    DocumentCountAccountQueryConfig,
    DocumentCountAccountQueryConfigQueryFilter,
)
from .document_count_account_query_response import DocumentCountAccountQueryResponse
from .document_count_account_group_query_config import (
    DocumentCountAccountGroupQueryConfig,
    DocumentCountAccountGroupQueryConfigQueryFilter,
)
from .document_count_account_group_query_response import (
    DocumentCountAccountGroupQueryResponse,
)
from .edifact_connector_record_query_config import (
    EdifactConnectorRecordQueryConfig,
    EdifactConnectorRecordQueryConfigQueryFilter,
)
from .edifact_connector_record_query_response import EdifactConnectorRecordQueryResponse
from .edi_custom_connector_record_query_config import (
    EdiCustomConnectorRecordQueryConfig,
    EdiCustomConnectorRecordQueryConfigQueryFilter,
)
from .edi_custom_connector_record_query_response import (
    EdiCustomConnectorRecordQueryResponse,
)
from .environment import Environment, EnvironmentClassification
from .environment_bulk_request import EnvironmentBulkRequest, EnvironmentBulkRequestType
from .environment_bulk_response import (
    EnvironmentBulkResponse,
    EnvironmentBulkResponseResponse,
)
from .environment_query_config import (
    EnvironmentQueryConfig,
    EnvironmentQueryConfigQueryFilter,
)
from .environment_query_response import EnvironmentQueryResponse
from .environment_map_extension import EnvironmentMapExtension
from .environment_atom_attachment import EnvironmentAtomAttachment
from .environment_atom_attachment_query_config import (
    EnvironmentAtomAttachmentQueryConfig,
    EnvironmentAtomAttachmentQueryConfigQueryFilter,
)
from .environment_atom_attachment_query_response import (
    EnvironmentAtomAttachmentQueryResponse,
)
from .environment_connection_field_extension_summary_query_config import (
    EnvironmentConnectionFieldExtensionSummaryQueryConfig,
    EnvironmentConnectionFieldExtensionSummaryQueryConfigQueryFilter,
)
from .environment_connection_field_extension_summary_query_response import (
    EnvironmentConnectionFieldExtensionSummaryQueryResponse,
)
from .environment_extensions import EnvironmentExtensions
from .environment_extensions_bulk_request import (
    EnvironmentExtensionsBulkRequest,
    EnvironmentExtensionsBulkRequestType,
)
from .environment_extensions_bulk_response import (
    EnvironmentExtensionsBulkResponse,
    EnvironmentExtensionsBulkResponseResponse,
)
from .environment_extensions_query_config import (
    EnvironmentExtensionsQueryConfig,
    EnvironmentExtensionsQueryConfigQueryFilter,
)
from .environment_extensions_query_response import EnvironmentExtensionsQueryResponse
from .environment_map_extension_bulk_request import (
    EnvironmentMapExtensionBulkRequest,
    EnvironmentMapExtensionBulkRequestType,
)
from .environment_map_extension_bulk_response import (
    EnvironmentMapExtensionBulkResponse,
    EnvironmentMapExtensionBulkResponseResponse,
)
from .environment_map_extension_external_component_query_config import (
    EnvironmentMapExtensionExternalComponentQueryConfig,
    EnvironmentMapExtensionExternalComponentQueryConfigQueryFilter,
)
from .environment_map_extension_external_component_query_response import (
    EnvironmentMapExtensionExternalComponentQueryResponse,
)
from .environment_map_extension_user_defined_function import (
    EnvironmentMapExtensionUserDefinedFunction,
)
from .environment_map_extension_user_defined_function_bulk_request import (
    EnvironmentMapExtensionUserDefinedFunctionBulkRequest,
    EnvironmentMapExtensionUserDefinedFunctionBulkRequestType,
)
from .environment_map_extension_user_defined_function_bulk_response import (
    EnvironmentMapExtensionUserDefinedFunctionBulkResponse,
    EnvironmentMapExtensionUserDefinedFunctionBulkResponseResponse,
)
from .environment_map_extension_user_defined_function_summary_query_config import (
    EnvironmentMapExtensionUserDefinedFunctionSummaryQueryConfig,
    EnvironmentMapExtensionUserDefinedFunctionSummaryQueryConfigQueryFilter,
)
from .environment_map_extension_user_defined_function_summary_query_response import (
    EnvironmentMapExtensionUserDefinedFunctionSummaryQueryResponse,
)
from .environment_map_extensions_summary_query_config import (
    EnvironmentMapExtensionsSummaryQueryConfig,
    EnvironmentMapExtensionsSummaryQueryConfigQueryFilter,
)
from .environment_map_extensions_summary_query_response import (
    EnvironmentMapExtensionsSummaryQueryResponse,
)
from .environment_role import EnvironmentRole
from .environment_role_bulk_request import (
    EnvironmentRoleBulkRequest,
    EnvironmentRoleBulkRequestType,
)
from .environment_role_bulk_response import (
    EnvironmentRoleBulkResponse,
    EnvironmentRoleBulkResponseResponse,
)
from .environment_role_query_config import (
    EnvironmentRoleQueryConfig,
    EnvironmentRoleQueryConfigQueryFilter,
)
from .environment_role_query_response import EnvironmentRoleQueryResponse
from .event_query_config import EventQueryConfig, EventQueryConfigQueryFilter
from .event_query_response import EventQueryResponse
from .execution_artifacts import ExecutionArtifacts
from .execution_connector_query_config import (
    ExecutionConnectorQueryConfig,
    ExecutionConnectorQueryConfigQueryFilter,
)
from .execution_connector_query_response import ExecutionConnectorQueryResponse
from .execution_count_account_query_config import (
    ExecutionCountAccountQueryConfig,
    ExecutionCountAccountQueryConfigQueryFilter,
)
from .execution_count_account_query_response import ExecutionCountAccountQueryResponse
from .execution_count_account_group_query_config import (
    ExecutionCountAccountGroupQueryConfig,
    ExecutionCountAccountGroupQueryConfigQueryFilter,
)
from .execution_count_account_group_query_response import (
    ExecutionCountAccountGroupQueryResponse,
)
from .execution_record_query_config import (
    ExecutionRecordQueryConfig,
    ExecutionRecordQueryConfigQueryFilter,
    QuerySort,
    SortField,
)
from .execution_record_query_response import ExecutionRecordQueryResponse
from .execution_request import ExecutionRequest
from .execution_summary_record_query_config import (
    ExecutionSummaryRecordQueryConfig,
    ExecutionSummaryRecordQueryConfigQueryFilter,
)
from .execution_summary_record_query_response import ExecutionSummaryRecordQueryResponse
from .folder import Folder
from .folder_bulk_request import FolderBulkRequest, FolderBulkRequestType
from .folder_bulk_response import FolderBulkResponse, FolderBulkResponseResponse
from .folder_query_config import FolderQueryConfig, FolderQueryConfigQueryFilter
from .folder_query_response import FolderQueryResponse
from .generic_connector_record import (
    GenericConnectorRecord,
    GenericConnectorRecordStatus,
)
from .generic_connector_record_bulk_request import (
    GenericConnectorRecordBulkRequest,
    GenericConnectorRecordBulkRequestType,
)
from .generic_connector_record_bulk_response import (
    GenericConnectorRecordBulkResponse,
    GenericConnectorRecordBulkResponseResponse,
)
from .generic_connector_record_query_config import (
    GenericConnectorRecordQueryConfig,
    GenericConnectorRecordQueryConfigQueryFilter,
)
from .generic_connector_record_query_response import GenericConnectorRecordQueryResponse
from .roles import Roles
from .hl7_connector_record_query_config import (
    Hl7ConnectorRecordQueryConfig,
    Hl7ConnectorRecordQueryConfigQueryFilter,
)
from .hl7_connector_record_query_response import Hl7ConnectorRecordQueryResponse
from .installer_token import InstallerToken, InstallType
from .integration_pack import IntegrationPack, IntegrationPackInstallationType
from .integration_pack_bulk_request import (
    IntegrationPackBulkRequest,
    IntegrationPackBulkRequestType,
)
from .integration_pack_bulk_response import (
    IntegrationPackBulkResponse,
    IntegrationPackBulkResponseResponse,
)
from .integration_pack_query_config import (
    IntegrationPackQueryConfig,
    IntegrationPackQueryConfigQueryFilter,
)
from .integration_pack_query_response import IntegrationPackQueryResponse
from .integration_pack_atom_attachment import IntegrationPackAtomAttachment
from .integration_pack_atom_attachment_query_config import (
    IntegrationPackAtomAttachmentQueryConfig,
    IntegrationPackAtomAttachmentQueryConfigQueryFilter,
)
from .integration_pack_atom_attachment_query_response import (
    IntegrationPackAtomAttachmentQueryResponse,
)
from .integration_pack_environment_attachment import (
    IntegrationPackEnvironmentAttachment,
)
from .integration_pack_environment_attachment_query_config import (
    IntegrationPackEnvironmentAttachmentQueryConfig,
    IntegrationPackEnvironmentAttachmentQueryConfigQueryFilter,
)
from .integration_pack_environment_attachment_query_response import (
    IntegrationPackEnvironmentAttachmentQueryResponse,
)
from .integration_pack_instance import IntegrationPackInstance
from .integration_pack_instance_bulk_request import (
    IntegrationPackInstanceBulkRequest,
    IntegrationPackInstanceBulkRequestType,
)
from .integration_pack_instance_bulk_response import (
    IntegrationPackInstanceBulkResponse,
    IntegrationPackInstanceBulkResponseResponse,
)
from .integration_pack_instance_query_config import (
    IntegrationPackInstanceQueryConfig,
    IntegrationPackInstanceQueryConfigQueryFilter,
)
from .integration_pack_instance_query_response import (
    IntegrationPackInstanceQueryResponse,
)
from .java_rollback import JavaRollback
from .java_upgrade import JavaUpgrade
from .merge_request import (
    MergeRequest,
    MergeRequestAction,
    PreviousStage,
    PriorityBranch,
    MergeRequestStage,
    Strategy,
)
from .merge_request_bulk_request import (
    MergeRequestBulkRequest,
    MergeRequestBulkRequestType,
)
from .merge_request_bulk_response import (
    MergeRequestBulkResponse,
    MergeRequestBulkResponseResponse,
)
from .merge_request_query_config import (
    MergeRequestQueryConfig,
    MergeRequestQueryConfigQueryFilter,
)
from .merge_request_query_response import MergeRequestQueryResponse
from .move_queue_request import MoveQueueRequest
from .node_offboard import NodeOffboard
from .odette_connector_record_query_config import (
    OdetteConnectorRecordQueryConfig,
    OdetteConnectorRecordQueryConfigQueryFilter,
)
from .odette_connector_record_query_response import OdetteConnectorRecordQueryResponse
from .oftp2_connector_record_query_config import (
    Oftp2ConnectorRecordQueryConfig,
    Oftp2ConnectorRecordQueryConfigQueryFilter,
)
from .oftp2_connector_record_query_response import Oftp2ConnectorRecordQueryResponse
from .packaged_component import PackagedComponent
from .packaged_component_bulk_request import (
    PackagedComponentBulkRequest,
    PackagedComponentBulkRequestType,
)
from .packaged_component_bulk_response import (
    PackagedComponentBulkResponse,
    PackagedComponentBulkResponseResponse,
)
from .packaged_component_query_config import (
    PackagedComponentQueryConfig,
    PackagedComponentQueryConfigQueryFilter,
)
from .packaged_component_query_response import PackagedComponentQueryResponse
from .packaged_component_manifest import PackagedComponentManifest
from .packaged_component_manifest_bulk_request import (
    PackagedComponentManifestBulkRequest,
    PackagedComponentManifestBulkRequestType,
)
from .packaged_component_manifest_bulk_response import (
    PackagedComponentManifestBulkResponse,
    PackagedComponentManifestBulkResponseResponse,
)
from .persisted_process_properties import PersistedProcessProperties
from .process import Process
from .process_bulk_request import ProcessBulkRequest, ProcessBulkRequestType
from .process_bulk_response import ProcessBulkResponse, ProcessBulkResponseResponse
from .process_query_config import ProcessQueryConfig, ProcessQueryConfigQueryFilter
from .process_query_response import ProcessQueryResponse
from .process_atom_attachment import ProcessAtomAttachment
from .process_atom_attachment_query_config import (
    ProcessAtomAttachmentQueryConfig,
    ProcessAtomAttachmentQueryConfigQueryFilter,
)
from .process_atom_attachment_query_response import ProcessAtomAttachmentQueryResponse
from .process_environment_attachment import ProcessEnvironmentAttachment
from .process_log import ProcessLog, LogLevel
from .process_schedule_status import ProcessScheduleStatus
from .process_schedule_status_bulk_request import (
    ProcessScheduleStatusBulkRequest,
    ProcessScheduleStatusBulkRequestType,
)
from .process_schedule_status_bulk_response import (
    ProcessScheduleStatusBulkResponse,
    ProcessScheduleStatusBulkResponseResponse,
)
from .process_schedule_status_query_config import (
    ProcessScheduleStatusQueryConfig,
    ProcessScheduleStatusQueryConfigQueryFilter,
)
from .process_schedule_status_query_response import ProcessScheduleStatusQueryResponse
from .process_schedules import ProcessSchedules
from .process_schedules_bulk_request import (
    ProcessSchedulesBulkRequest,
    ProcessSchedulesBulkRequestType,
)
from .process_schedules_bulk_response import (
    ProcessSchedulesBulkResponse,
    ProcessSchedulesBulkResponseResponse,
)
from .process_schedules_query_config import (
    ProcessSchedulesQueryConfig,
    ProcessSchedulesQueryConfigQueryFilter,
)
from .process_schedules_query_response import ProcessSchedulesQueryResponse
from .rerun_document import RerunDocument
from .role import Role
from .role_bulk_request import RoleBulkRequest, RoleBulkRequestType
from .role_bulk_response import RoleBulkResponse, RoleBulkResponseResponse
from .role_query_config import RoleQueryConfig, RoleQueryConfigQueryFilter
from .role_query_response import RoleQueryResponse
from .rosetta_net_connector_record_query_config import (
    RosettaNetConnectorRecordQueryConfig,
    RosettaNetConnectorRecordQueryConfigQueryFilter,
)
from .rosetta_net_connector_record_query_response import (
    RosettaNetConnectorRecordQueryResponse,
)
from .runtime_release_schedule import RuntimeReleaseSchedule, ScheduleType
from .runtime_release_schedule_bulk_request import (
    RuntimeReleaseScheduleBulkRequest,
    RuntimeReleaseScheduleBulkRequestType,
)
from .runtime_release_schedule_bulk_response import (
    RuntimeReleaseScheduleBulkResponse,
    RuntimeReleaseScheduleBulkResponseResponse,
)
from .shared_server_information import SharedServerInformation, ApiType, Auth, MinAuth
from .shared_server_information_bulk_request import (
    SharedServerInformationBulkRequest,
    SharedServerInformationBulkRequestType,
)
from .shared_server_information_bulk_response import (
    SharedServerInformationBulkResponse,
    SharedServerInformationBulkResponseResponse,
)
from .shared_web_server import SharedWebServer
from .shared_web_server_bulk_request import (
    SharedWebServerBulkRequest,
    SharedWebServerBulkRequestType,
)
from .shared_web_server_bulk_response import (
    SharedWebServerBulkResponse,
    SharedWebServerBulkResponseResponse,
)
from .throughput_account_query_config import (
    ThroughputAccountQueryConfig,
    ThroughputAccountQueryConfigQueryFilter,
)
from .throughput_account_query_response import ThroughputAccountQueryResponse
from .throughput_account_group_query_config import (
    ThroughputAccountGroupQueryConfig,
    ThroughputAccountGroupQueryConfigQueryFilter,
)
from .throughput_account_group_query_response import ThroughputAccountGroupQueryResponse
from .tradacoms_connector_record_query_config import (
    TradacomsConnectorRecordQueryConfig,
    TradacomsConnectorRecordQueryConfigQueryFilter,
)
from .tradacoms_connector_record_query_response import (
    TradacomsConnectorRecordQueryResponse,
)
from .trading_partner_component import (
    TradingPartnerComponent,
    TradingPartnerComponentClassification,
    TradingPartnerComponentStandard,
)
from .trading_partner_component_bulk_request import (
    TradingPartnerComponentBulkRequest,
    TradingPartnerComponentBulkRequestType,
)
from .trading_partner_component_bulk_response import (
    TradingPartnerComponentBulkResponse,
    TradingPartnerComponentBulkResponseResponse,
)
from .trading_partner_component_query_config import (
    TradingPartnerComponentQueryConfig,
    TradingPartnerComponentQueryConfigQueryFilter,
)
from .trading_partner_component_query_response import (
    TradingPartnerComponentQueryResponse,
)
from .trading_partner_processing_group import TradingPartnerProcessingGroup
from .trading_partner_processing_group_bulk_request import (
    TradingPartnerProcessingGroupBulkRequest,
    TradingPartnerProcessingGroupBulkRequestType,
)
from .trading_partner_processing_group_bulk_response import (
    TradingPartnerProcessingGroupBulkResponse,
    TradingPartnerProcessingGroupBulkResponseResponse,
)
from .trading_partner_processing_group_query_config import (
    TradingPartnerProcessingGroupQueryConfig,
    TradingPartnerProcessingGroupQueryConfigQueryFilter,
)
from .trading_partner_processing_group_query_response import (
    TradingPartnerProcessingGroupQueryResponse,
)
from .x12_connector_record_query_config import (
    X12ConnectorRecordQueryConfig,
    X12ConnectorRecordQueryConfigQueryFilter,
)
from .x12_connector_record_query_response import X12ConnectorRecordQueryResponse
from .atom_disk_space_async_response import AtomDiskSpaceAsyncResponse
from .list_queues_async_response import ListQueuesAsyncResponse
from .listener_status_query_config import (
    ListenerStatusQueryConfig,
    ListenerStatusQueryConfigQueryFilter,
)
from .listener_status_async_response import (
    ListenerStatusAsyncResponse,
    ResponseStatusCode,
)
from .organization_component import OrganizationComponent
from .organization_component_bulk_request import (
    OrganizationComponentBulkRequest,
    OrganizationComponentBulkRequestType,
)
from .organization_component_bulk_response import (
    OrganizationComponentBulkResponse,
    OrganizationComponentBulkResponseResponse,
)
from .organization_component_query_config import (
    OrganizationComponentQueryConfig,
    OrganizationComponentQueryConfigQueryFilter,
)
from .organization_component_query_response import OrganizationComponentQueryResponse
from .shared_communication_channel_component import SharedCommunicationChannelComponent
from .shared_communication_channel_component_bulk_request import (
    SharedCommunicationChannelComponentBulkRequest,
    SharedCommunicationChannelComponentBulkRequestType,
)
from .shared_communication_channel_component_bulk_response import (
    SharedCommunicationChannelComponentBulkResponse,
    SharedCommunicationChannelComponentBulkResponseResponse,
)
from .shared_communication_channel_component_query_config import (
    SharedCommunicationChannelComponentQueryConfig,
    SharedCommunicationChannelComponentQueryConfigQueryFilter,
)
from .shared_communication_channel_component_query_response import (
    SharedCommunicationChannelComponentQueryResponse,
)
from .account_group_integration_pack import (
    AccountGroupIntegrationPack,
    AccountGroupIntegrationPackInstallationType,
)
from .account_group_integration_pack_bulk_request import (
    AccountGroupIntegrationPackBulkRequest,
    AccountGroupIntegrationPackBulkRequestType,
)
from .account_group_integration_pack_bulk_response import (
    AccountGroupIntegrationPackBulkResponse,
    AccountGroupIntegrationPackBulkResponseResponse,
)
from .account_group_integration_pack_query_config import (
    AccountGroupIntegrationPackQueryConfig,
    AccountGroupIntegrationPackQueryConfigQueryFilter,
)
from .account_group_integration_pack_query_response import (
    AccountGroupIntegrationPackQueryResponse,
)
from .publisher_integration_pack import (
    PublisherIntegrationPack,
    PublisherIntegrationPackInstallationType,
    OperationType,
)
from .publisher_integration_pack_bulk_request import (
    PublisherIntegrationPackBulkRequest,
    PublisherIntegrationPackBulkRequestType,
)
from .publisher_integration_pack_bulk_response import (
    PublisherIntegrationPackBulkResponse,
    PublisherIntegrationPackBulkResponseResponse,
)
from .publisher_integration_pack_query_config import (
    PublisherIntegrationPackQueryConfig,
    PublisherIntegrationPackQueryConfigQueryFilter,
)
from .publisher_integration_pack_query_response import (
    PublisherIntegrationPackQueryResponse,
)
from .release_integration_pack import (
    ReleaseIntegrationPack,
    ReleaseIntegrationPackInstallationType,
    ReleaseIntegrationPackReleaseSchedule,
)
from .release_integration_pack_status import (
    ReleaseIntegrationPackStatus,
    ReleaseIntegrationPackStatusInstallationType,
    ReleaseIntegrationPackStatusReleaseSchedule,
    ReleaseStatus,
)
from .release_integration_pack_status_bulk_request import (
    ReleaseIntegrationPackStatusBulkRequest,
    ReleaseIntegrationPackStatusBulkRequestType,
)
from .release_integration_pack_status_bulk_response import (
    ReleaseIntegrationPackStatusBulkResponse,
    ReleaseIntegrationPackStatusBulkResponseResponse,
)
from .runtime_restart_request import RuntimeRestartRequest
from .secrets_manager_refresh_request import SecretsManagerRefreshRequest, Provider
from .secrets_manager_refresh_response import SecretsManagerRefreshResponse
from .as2_connector_record_expression import As2ConnectorRecordExpression
from .as2_connector_record_simple_expression import (
    As2ConnectorRecordSimpleExpression,
    As2ConnectorRecordSimpleExpressionOperator,
)
from .as2_connector_record_grouping_expression import (
    As2ConnectorRecordGroupingExpression,
    As2ConnectorRecordGroupingExpressionOperator,
)
from .as2_connector_record import As2ConnectorRecord
from .custom_fields import CustomFields
from .licensing import Licensing
from .molecule import Molecule
from .license import License
from .bulk_id import BulkId
from .account_expression import AccountExpression
from .account_simple_expression import (
    AccountSimpleExpression,
    AccountSimpleExpressionOperator,
    AccountSimpleExpressionProperty,
)
from .account_grouping_expression import (
    AccountGroupingExpression,
    AccountGroupingExpressionOperator,
)
from .async_token import AsyncToken
from .resources import Resources
from .resource import Resource, ObjectType
from .account_group_expression import AccountGroupExpression
from .account_group_simple_expression import (
    AccountGroupSimpleExpression,
    AccountGroupSimpleExpressionOperator,
    AccountGroupSimpleExpressionProperty,
)
from .account_group_grouping_expression import (
    AccountGroupGroupingExpression,
    AccountGroupGroupingExpressionOperator,
)
from .account_group_account_expression import AccountGroupAccountExpression
from .account_group_account_simple_expression import (
    AccountGroupAccountSimpleExpression,
    AccountGroupAccountSimpleExpressionOperator,
    AccountGroupAccountSimpleExpressionProperty,
)
from .account_group_account_grouping_expression import (
    AccountGroupAccountGroupingExpression,
    AccountGroupAccountGroupingExpressionOperator,
)
from .account_group_user_role_expression import AccountGroupUserRoleExpression
from .account_group_user_role_simple_expression import (
    AccountGroupUserRoleSimpleExpression,
    AccountGroupUserRoleSimpleExpressionOperator,
    AccountGroupUserRoleSimpleExpressionProperty,
)
from .account_group_user_role_grouping_expression import (
    AccountGroupUserRoleGroupingExpression,
    AccountGroupUserRoleGroupingExpressionOperator,
)
from .account_user_federation_expression import AccountUserFederationExpression
from .account_user_federation_simple_expression import (
    AccountUserFederationSimpleExpression,
    AccountUserFederationSimpleExpressionOperator,
    AccountUserFederationSimpleExpressionProperty,
)
from .account_user_federation_grouping_expression import (
    AccountUserFederationGroupingExpression,
    AccountUserFederationGroupingExpressionOperator,
)
from .account_user_role_expression import AccountUserRoleExpression
from .account_user_role_simple_expression import (
    AccountUserRoleSimpleExpression,
    AccountUserRoleSimpleExpressionOperator,
    AccountUserRoleSimpleExpressionProperty,
)
from .account_user_role_grouping_expression import (
    AccountUserRoleGroupingExpression,
    AccountUserRoleGroupingExpressionOperator,
)
from .api_usage_count_expression import ApiUsageCountExpression
from .api_usage_count_simple_expression import (
    ApiUsageCountSimpleExpression,
    ApiUsageCountSimpleExpressionOperator,
    ApiUsageCountSimpleExpressionProperty,
)
from .api_usage_count_grouping_expression import (
    ApiUsageCountGroupingExpression,
    ApiUsageCountGroupingExpressionOperator,
)
from .api_usage_count import ApiUsageCount, ApiUsageCountClassification
from .nodes import Nodes
from .node_details import NodeDetails
from .atom_expression import AtomExpression
from .atom_simple_expression import (
    AtomSimpleExpression,
    AtomSimpleExpressionOperator,
    AtomSimpleExpressionProperty,
)
from .atom_grouping_expression import (
    AtomGroupingExpression,
    AtomGroupingExpressionOperator,
)
from .counter import Counter
from .deployed_process import DeployedProcess
from .process_properties import ProcessProperties
from .process_property import ProcessProperty
from .process_property_value import ProcessPropertyValue
from .atom_connection_field_extension_summary_expression import (
    AtomConnectionFieldExtensionSummaryExpression,
)
from .atom_connection_field_extension_summary_simple_expression import (
    AtomConnectionFieldExtensionSummarySimpleExpression,
    AtomConnectionFieldExtensionSummarySimpleExpressionOperator,
    AtomConnectionFieldExtensionSummarySimpleExpressionProperty,
)
from .atom_connection_field_extension_summary_grouping_expression import (
    AtomConnectionFieldExtensionSummaryGroupingExpression,
    AtomConnectionFieldExtensionSummaryGroupingExpressionOperator,
)
from .atom_connection_field_extension_summary import AtomConnectionFieldExtensionSummary
from .field_summary import FieldSummary
from .custom_properties import CustomProperties
from .property_pair import PropertyPair
from .connector_version import ConnectorVersion
from .atom_security_policies_type import AtomSecurityPoliciesType
from .atom_security_policy import AtomSecurityPolicy
from .atom_security_policy_argument_type import AtomSecurityPolicyArgumentType
from .property import Property
from .audit_log_property import AuditLogProperty
from .audit_log_expression import AuditLogExpression
from .audit_log_simple_expression import (
    AuditLogSimpleExpression,
    AuditLogSimpleExpressionOperator,
    AuditLogSimpleExpressionProperty,
)
from .audit_log_grouping_expression import (
    AuditLogGroupingExpression,
    AuditLogGroupingExpressionOperator,
)
from .branch_expression import BranchExpression
from .branch_simple_expression import (
    BranchSimpleExpression,
    BranchSimpleExpressionOperator,
)
from .branch_grouping_expression import (
    BranchGroupingExpression,
    BranchGroupingExpressionOperator,
)
from .cloud_atom import CloudAtom
from .cloud_expression import CloudExpression
from .cloud_simple_expression import (
    CloudSimpleExpression,
    CloudSimpleExpressionOperator,
    CloudSimpleExpressionProperty,
)
from .cloud_grouping_expression import (
    CloudGroupingExpression,
    CloudGroupingExpressionOperator,
)
from .encrypted_values import EncryptedValues
from .encrypted_value import EncryptedValue
from .component_atom_attachment_expression import ComponentAtomAttachmentExpression
from .component_atom_attachment_simple_expression import (
    ComponentAtomAttachmentSimpleExpression,
    ComponentAtomAttachmentSimpleExpressionOperator,
    ComponentAtomAttachmentSimpleExpressionProperty,
)
from .component_atom_attachment_grouping_expression import (
    ComponentAtomAttachmentGroupingExpression,
    ComponentAtomAttachmentGroupingExpressionOperator,
)
from .comp_diff_config import CompDiffConfig, CompDiffConfigComponentType
from .comp_diff_element import CompDiffElement
from .comp_diff_attribute import CompDiffAttribute
from .component_environment_attachment_expression import (
    ComponentEnvironmentAttachmentExpression,
)
from .component_environment_attachment_simple_expression import (
    ComponentEnvironmentAttachmentSimpleExpression,
    ComponentEnvironmentAttachmentSimpleExpressionOperator,
    ComponentEnvironmentAttachmentSimpleExpressionProperty,
)
from .component_environment_attachment_grouping_expression import (
    ComponentEnvironmentAttachmentGroupingExpression,
    ComponentEnvironmentAttachmentGroupingExpressionOperator,
)
from .component_metadata_expression import ComponentMetadataExpression
from .component_metadata_simple_expression import (
    ComponentMetadataSimpleExpression,
    ComponentMetadataSimpleExpressionOperator,
    ComponentMetadataSimpleExpressionProperty,
)
from .component_metadata_grouping_expression import (
    ComponentMetadataGroupingExpression,
    ComponentMetadataGroupingExpressionOperator,
)
from .references import References, ReferencesType
from .component_reference_expression import ComponentReferenceExpression
from .component_reference_simple_expression import (
    ComponentReferenceSimpleExpression,
    ComponentReferenceSimpleExpressionOperator,
    ComponentReferenceSimpleExpressionProperty,
)
from .component_reference_grouping_expression import (
    ComponentReferenceGroupingExpression,
    ComponentReferenceGroupingExpressionOperator,
)
from .query_filter import QueryFilter
from .connector_expression import ConnectorExpression
from .connector_simple_expression import (
    ConnectorSimpleExpression,
    ConnectorSimpleExpressionOperator,
    ConnectorSimpleExpressionProperty,
)
from .connector_grouping_expression import (
    ConnectorGroupingExpression,
    ConnectorGroupingExpressionOperator,
)
from .custom_tracked_field_expression import CustomTrackedFieldExpression
from .custom_tracked_field_simple_expression import (
    CustomTrackedFieldSimpleExpression,
    CustomTrackedFieldSimpleExpressionOperator,
)
from .custom_tracked_field_grouping_expression import (
    CustomTrackedFieldGroupingExpression,
    CustomTrackedFieldGroupingExpressionOperator,
)
from .custom_tracked_field import CustomTrackedField, CustomTrackedFieldType
from .deployed_expired_certificate_expression import (
    DeployedExpiredCertificateExpression,
)
from .deployed_expired_certificate_simple_expression import (
    DeployedExpiredCertificateSimpleExpression,
    DeployedExpiredCertificateSimpleExpressionOperator,
    DeployedExpiredCertificateSimpleExpressionProperty,
)
from .deployed_expired_certificate_grouping_expression import (
    DeployedExpiredCertificateGroupingExpression,
    DeployedExpiredCertificateGroupingExpressionOperator,
)
from .deployed_expired_certificate import DeployedExpiredCertificate
from .deployed_package_expression import DeployedPackageExpression
from .deployed_package_simple_expression import (
    DeployedPackageSimpleExpression,
    DeployedPackageSimpleExpressionOperator,
    DeployedPackageSimpleExpressionProperty,
)
from .deployed_package_grouping_expression import (
    DeployedPackageGroupingExpression,
    DeployedPackageGroupingExpressionOperator,
)
from .deployment_expression import DeploymentExpression
from .deployment_simple_expression import (
    DeploymentSimpleExpression,
    DeploymentSimpleExpressionOperator,
    DeploymentSimpleExpressionProperty,
)
from .deployment_grouping_expression import (
    DeploymentGroupingExpression,
    DeploymentGroupingExpressionOperator,
)
from .process_environment_attachment_expression import (
    ProcessEnvironmentAttachmentExpression,
)
from .process_environment_attachment_simple_expression import (
    ProcessEnvironmentAttachmentSimpleExpression,
    ProcessEnvironmentAttachmentSimpleExpressionOperator,
    ProcessEnvironmentAttachmentSimpleExpressionProperty,
)
from .process_environment_attachment_grouping_expression import (
    ProcessEnvironmentAttachmentGroupingExpression,
    ProcessEnvironmentAttachmentGroupingExpressionOperator,
)
from .document_count_account_expression import DocumentCountAccountExpression
from .document_count_account_simple_expression import (
    DocumentCountAccountSimpleExpression,
    DocumentCountAccountSimpleExpressionOperator,
    DocumentCountAccountSimpleExpressionProperty,
)
from .document_count_account_grouping_expression import (
    DocumentCountAccountGroupingExpression,
    DocumentCountAccountGroupingExpressionOperator,
)
from .document_count_account import DocumentCountAccount
from .document_count_account_group_expression import DocumentCountAccountGroupExpression
from .document_count_account_group_simple_expression import (
    DocumentCountAccountGroupSimpleExpression,
    DocumentCountAccountGroupSimpleExpressionOperator,
    DocumentCountAccountGroupSimpleExpressionProperty,
)
from .document_count_account_group_grouping_expression import (
    DocumentCountAccountGroupGroupingExpression,
    DocumentCountAccountGroupGroupingExpressionOperator,
)
from .edifact_connector_record_expression import EdifactConnectorRecordExpression
from .edifact_connector_record_simple_expression import (
    EdifactConnectorRecordSimpleExpression,
    EdifactConnectorRecordSimpleExpressionOperator,
    EdifactConnectorRecordSimpleExpressionProperty,
)
from .edifact_connector_record_grouping_expression import (
    EdifactConnectorRecordGroupingExpression,
    EdifactConnectorRecordGroupingExpressionOperator,
)
from .edifact_connector_record import EdifactConnectorRecord
from .edi_custom_connector_record_expression import EdiCustomConnectorRecordExpression
from .edi_custom_connector_record_simple_expression import (
    EdiCustomConnectorRecordSimpleExpression,
    EdiCustomConnectorRecordSimpleExpressionOperator,
)
from .edi_custom_connector_record_grouping_expression import (
    EdiCustomConnectorRecordGroupingExpression,
    EdiCustomConnectorRecordGroupingExpressionOperator,
)
from .edi_custom_connector_record import EdiCustomConnectorRecord
from .environment_expression import EnvironmentExpression
from .environment_simple_expression import (
    EnvironmentSimpleExpression,
    EnvironmentSimpleExpressionOperator,
    EnvironmentSimpleExpressionProperty,
)
from .environment_grouping_expression import (
    EnvironmentGroupingExpression,
    EnvironmentGroupingExpressionOperator,
)
from .map_extension import MapExtension
from .map_extension_browse_settings import MapExtensionBrowseSettings
from .map_extensions_profile import MapExtensionsProfile
from .map_extension_extend_profile import MapExtensionExtendProfile
from .map_extensions_functions import MapExtensionsFunctions
from .map_extensions_extended_mappings import MapExtensionsExtendedMappings
from .map_extension_browse import MapExtensionBrowse
from .browse_field import BrowseField
from .map_extensions_node import MapExtensionsNode
from .map_extensions_extended_node import MapExtensionsExtendedNode
from .map_extensions_date_time import MapExtensionsDateTime
from .map_extensions_number import MapExtensionsNumber
from .map_extensions_function import (
    MapExtensionsFunction,
    MapExtensionsFunctionCacheType,
    MapExtensionsFunctionType,
)
from .map_extensions_configuration import MapExtensionsConfiguration
from .map_extensions_inputs import MapExtensionsInputs
from .map_extensions_outputs import MapExtensionsOutputs
from .map_extensions_cross_reference_lookup import MapExtensionsCrossReferenceLookup
from .map_extensions_doc_cache_lookup import MapExtensionsDocCacheLookup
from .map_extensions_document_property import MapExtensionsDocumentProperty
from .map_extensions_japanese_character_conversion import (
    MapExtensionsJapaneseCharacterConversion,
)
from .map_extensions_scripting import MapExtensionsScripting, Language
from .map_extensions_sequential_value import MapExtensionsSequentialValue
from .map_extensions_simple_lookup import MapExtensionsSimpleLookup
from .map_extensions_string_concat import MapExtensionsStringConcat
from .map_extensions_string_split import MapExtensionsStringSplit
from .map_extensions_user_defined_function import MapExtensionsUserDefinedFunction
from .cross_reference_inputs import CrossReferenceInputs
from .cross_reference_outputs import CrossReferenceOutputs
from .cross_reference_parameter import CrossReferenceParameter
from .doc_cache_key_inputs import DocCacheKeyInputs
from .doc_cache_profile_parameters import DocCacheProfileParameters
from .doc_cache_key_input import DocCacheKeyInput
from .doc_cache_profile_parameter import DocCacheProfileParameter
from .scripting_inputs import ScriptingInputs
from .scripting_outputs import ScriptingOutputs
from .scripting_parameter import ScriptingParameter, DataType
from .simple_lookup_table import SimpleLookupTable
from .simple_lookup_table_rows import SimpleLookupTableRows
from .simple_lookup_table_row import SimpleLookupTableRow
from .map_extensions_input import MapExtensionsInput
from .map_extensions_output import MapExtensionsOutput
from .map_extensions_mapping import MapExtensionsMapping
from .environment_atom_attachment_expression import EnvironmentAtomAttachmentExpression
from .environment_atom_attachment_simple_expression import (
    EnvironmentAtomAttachmentSimpleExpression,
    EnvironmentAtomAttachmentSimpleExpressionOperator,
    EnvironmentAtomAttachmentSimpleExpressionProperty,
)
from .environment_atom_attachment_grouping_expression import (
    EnvironmentAtomAttachmentGroupingExpression,
    EnvironmentAtomAttachmentGroupingExpressionOperator,
)
from .environment_connection_field_extension_summary_expression import (
    EnvironmentConnectionFieldExtensionSummaryExpression,
)
from .environment_connection_field_extension_summary_simple_expression import (
    EnvironmentConnectionFieldExtensionSummarySimpleExpression,
    EnvironmentConnectionFieldExtensionSummarySimpleExpressionOperator,
    EnvironmentConnectionFieldExtensionSummarySimpleExpressionProperty,
)
from .environment_connection_field_extension_summary_grouping_expression import (
    EnvironmentConnectionFieldExtensionSummaryGroupingExpression,
    EnvironmentConnectionFieldExtensionSummaryGroupingExpressionOperator,
)
from .environment_connection_field_extension_summary import (
    EnvironmentConnectionFieldExtensionSummary,
)
from .pgp_certificates import PgpCertificates
from .connections import Connections
from .cross_references import CrossReferences
from .operations import Operations
from .override_process_properties import OverrideProcessProperties
from .properties import Properties
from .shared_communications import SharedCommunications
from .trading_partners import TradingPartners
from .pgp_certificate import PgpCertificate
from .connection import Connection
from .field import Field
from .cross_reference import CrossReference
from .cross_reference_rows import CrossReferenceRows
from .cross_reference_row import CrossReferenceRow
from .operation import Operation
from .override_process_property import OverrideProcessProperty
from .shared_communication import SharedCommunication
from .trading_partner import TradingPartner
from .trading_partner_category import TradingPartnerCategory
from .environment_extensions_expression import EnvironmentExtensionsExpression
from .environment_extensions_simple_expression import (
    EnvironmentExtensionsSimpleExpression,
    EnvironmentExtensionsSimpleExpressionOperator,
    EnvironmentExtensionsSimpleExpressionProperty,
)
from .environment_extensions_grouping_expression import (
    EnvironmentExtensionsGroupingExpression,
    EnvironmentExtensionsGroupingExpressionOperator,
)
from .environment_map_extension_external_component_expression import (
    EnvironmentMapExtensionExternalComponentExpression,
)
from .environment_map_extension_external_component_simple_expression import (
    EnvironmentMapExtensionExternalComponentSimpleExpression,
    EnvironmentMapExtensionExternalComponentSimpleExpressionOperator,
    EnvironmentMapExtensionExternalComponentSimpleExpressionProperty,
)
from .environment_map_extension_external_component_grouping_expression import (
    EnvironmentMapExtensionExternalComponentGroupingExpression,
    EnvironmentMapExtensionExternalComponentGroupingExpressionOperator,
)
from .environment_map_extension_external_component import (
    EnvironmentMapExtensionExternalComponent,
)
from .map_extensions_function_mappings import MapExtensionsFunctionMappings
from .map_extensions_function_steps import MapExtensionsFunctionSteps
from .map_extensions_function_mapping import MapExtensionsFunctionMapping
from .map_extensions_function_step import (
    MapExtensionsFunctionStep,
    MapExtensionsFunctionStepCacheType,
    MapExtensionsFunctionStepType,
)
from .environment_map_extension_user_defined_function_summary_expression import (
    EnvironmentMapExtensionUserDefinedFunctionSummaryExpression,
)
from .environment_map_extension_user_defined_function_summary_simple_expression import (
    EnvironmentMapExtensionUserDefinedFunctionSummarySimpleExpression,
    EnvironmentMapExtensionUserDefinedFunctionSummarySimpleExpressionOperator,
    EnvironmentMapExtensionUserDefinedFunctionSummarySimpleExpressionProperty,
)
from .environment_map_extension_user_defined_function_summary_grouping_expression import (
    EnvironmentMapExtensionUserDefinedFunctionSummaryGroupingExpression,
    EnvironmentMapExtensionUserDefinedFunctionSummaryGroupingExpressionOperator,
)
from .environment_map_extension_user_defined_function_summary import (
    EnvironmentMapExtensionUserDefinedFunctionSummary,
)
from .environment_map_extensions_summary_expression import (
    EnvironmentMapExtensionsSummaryExpression,
)
from .environment_map_extensions_summary_simple_expression import (
    EnvironmentMapExtensionsSummarySimpleExpression,
    EnvironmentMapExtensionsSummarySimpleExpressionOperator,
    EnvironmentMapExtensionsSummarySimpleExpressionProperty,
)
from .environment_map_extensions_summary_grouping_expression import (
    EnvironmentMapExtensionsSummaryGroupingExpression,
    EnvironmentMapExtensionsSummaryGroupingExpressionOperator,
)
from .environment_map_extensions_summary import EnvironmentMapExtensionsSummary
from .map_extension_browse_data import MapExtensionBrowseData
from .environment_role_expression import EnvironmentRoleExpression
from .environment_role_simple_expression import (
    EnvironmentRoleSimpleExpression,
    EnvironmentRoleSimpleExpressionOperator,
    EnvironmentRoleSimpleExpressionProperty,
)
from .environment_role_grouping_expression import (
    EnvironmentRoleGroupingExpression,
    EnvironmentRoleGroupingExpressionOperator,
)
from .event_expression import EventExpression
from .event_simple_expression import (
    EventSimpleExpression,
    EventSimpleExpressionOperator,
    EventSimpleExpressionProperty,
)
from .event_grouping_expression import (
    EventGroupingExpression,
    EventGroupingExpressionOperator,
)
from .event import Event
from .execution_connector_expression import ExecutionConnectorExpression
from .execution_connector_simple_expression import (
    ExecutionConnectorSimpleExpression,
    ExecutionConnectorSimpleExpressionOperator,
    ExecutionConnectorSimpleExpressionProperty,
)
from .execution_connector_grouping_expression import (
    ExecutionConnectorGroupingExpression,
    ExecutionConnectorGroupingExpressionOperator,
)
from .execution_connector import ExecutionConnector
from .execution_count_account_expression import ExecutionCountAccountExpression
from .execution_count_account_simple_expression import (
    ExecutionCountAccountSimpleExpression,
    ExecutionCountAccountSimpleExpressionOperator,
    ExecutionCountAccountSimpleExpressionProperty,
)
from .execution_count_account_grouping_expression import (
    ExecutionCountAccountGroupingExpression,
    ExecutionCountAccountGroupingExpressionOperator,
)
from .execution_count_account import ExecutionCountAccount
from .execution_count_account_group_expression import (
    ExecutionCountAccountGroupExpression,
)
from .execution_count_account_group_simple_expression import (
    ExecutionCountAccountGroupSimpleExpression,
    ExecutionCountAccountGroupSimpleExpressionOperator,
    ExecutionCountAccountGroupSimpleExpressionProperty,
)
from .execution_count_account_group_grouping_expression import (
    ExecutionCountAccountGroupGroupingExpression,
    ExecutionCountAccountGroupGroupingExpressionOperator,
)
from .execution_record_expression import ExecutionRecordExpression
from .execution_record_simple_expression import (
    ExecutionRecordSimpleExpression,
    ExecutionRecordSimpleExpressionOperator,
    ExecutionRecordSimpleExpressionProperty,
)
from .execution_record_grouping_expression import (
    ExecutionRecordGroupingExpression,
    ExecutionRecordGroupingExpressionOperator,
)
from .execution_record import ExecutionRecord, ExecutionType
from .execution_request_dynamic_process_properties import (
    ExecutionRequestDynamicProcessProperties,
)
from .execution_request_process_properties import ExecutionRequestProcessProperties
from .dynamic_process_property import DynamicProcessProperty
from .execution_summary_record_expression import ExecutionSummaryRecordExpression
from .execution_summary_record_simple_expression import (
    ExecutionSummaryRecordSimpleExpression,
    ExecutionSummaryRecordSimpleExpressionOperator,
    ExecutionSummaryRecordSimpleExpressionProperty,
)
from .execution_summary_record_grouping_expression import (
    ExecutionSummaryRecordGroupingExpression,
    ExecutionSummaryRecordGroupingExpressionOperator,
)
from .execution_summary_record import ExecutionSummaryRecord
from .permitted_roles import PermittedRoles
from .role_reference import RoleReference
from .folder_expression import FolderExpression
from .folder_simple_expression import (
    FolderSimpleExpression,
    FolderSimpleExpressionOperator,
    FolderSimpleExpressionProperty,
)
from .folder_grouping_expression import (
    FolderGroupingExpression,
    FolderGroupingExpressionOperator,
)
from .connector_fields import ConnectorFields
from .tracked_fields import TrackedFields
from .connector_field import ConnectorField
from .tracked_field import TrackedField
from .generic_connector_record_expression import GenericConnectorRecordExpression
from .generic_connector_record_simple_expression import (
    GenericConnectorRecordSimpleExpression,
    GenericConnectorRecordSimpleExpressionOperator,
    GenericConnectorRecordSimpleExpressionProperty,
)
from .generic_connector_record_grouping_expression import (
    GenericConnectorRecordGroupingExpression,
    GenericConnectorRecordGroupingExpressionOperator,
)
from .privileges import Privileges
from .privilege import Privilege
from .hl7_connector_record_expression import Hl7ConnectorRecordExpression
from .hl7_connector_record_simple_expression import (
    Hl7ConnectorRecordSimpleExpression,
    Hl7ConnectorRecordSimpleExpressionOperator,
)
from .hl7_connector_record_grouping_expression import (
    Hl7ConnectorRecordGroupingExpression,
    Hl7ConnectorRecordGroupingExpressionOperator,
)
from .hl7_connector_record import Hl7ConnectorRecord
from .integration_pack_expression import IntegrationPackExpression
from .integration_pack_simple_expression import (
    IntegrationPackSimpleExpression,
    IntegrationPackSimpleExpressionOperator,
    IntegrationPackSimpleExpressionProperty,
)
from .integration_pack_grouping_expression import (
    IntegrationPackGroupingExpression,
    IntegrationPackGroupingExpressionOperator,
)
from .integration_pack_atom_attachment_expression import (
    IntegrationPackAtomAttachmentExpression,
)
from .integration_pack_atom_attachment_simple_expression import (
    IntegrationPackAtomAttachmentSimpleExpression,
    IntegrationPackAtomAttachmentSimpleExpressionOperator,
    IntegrationPackAtomAttachmentSimpleExpressionProperty,
)
from .integration_pack_atom_attachment_grouping_expression import (
    IntegrationPackAtomAttachmentGroupingExpression,
    IntegrationPackAtomAttachmentGroupingExpressionOperator,
)
from .integration_pack_environment_attachment_expression import (
    IntegrationPackEnvironmentAttachmentExpression,
)
from .integration_pack_environment_attachment_simple_expression import (
    IntegrationPackEnvironmentAttachmentSimpleExpression,
    IntegrationPackEnvironmentAttachmentSimpleExpressionOperator,
    IntegrationPackEnvironmentAttachmentSimpleExpressionProperty,
)
from .integration_pack_environment_attachment_grouping_expression import (
    IntegrationPackEnvironmentAttachmentGroupingExpression,
    IntegrationPackEnvironmentAttachmentGroupingExpressionOperator,
)
from .process_id import ProcessId
from .integration_pack_instance_expression import IntegrationPackInstanceExpression
from .integration_pack_instance_simple_expression import (
    IntegrationPackInstanceSimpleExpression,
    IntegrationPackInstanceSimpleExpressionOperator,
    IntegrationPackInstanceSimpleExpressionProperty,
)
from .integration_pack_instance_grouping_expression import (
    IntegrationPackInstanceGroupingExpression,
    IntegrationPackInstanceGroupingExpressionOperator,
)
from .java_upgrade_options import JavaUpgradeOptions
from .merge_request_details import MergeRequestDetails
from .merge_request_detail import (
    MergeRequestDetail,
    ChangeType,
    Resolution,
    MergeRequestDetailStage,
)
from .merge_request_expression import MergeRequestExpression
from .merge_request_simple_expression import (
    MergeRequestSimpleExpression,
    MergeRequestSimpleExpressionOperator,
)
from .merge_request_grouping_expression import (
    MergeRequestGroupingExpression,
    MergeRequestGroupingExpressionOperator,
)
from .queue_attributes import QueueAttributes
from .odette_connector_record_expression import OdetteConnectorRecordExpression
from .odette_connector_record_simple_expression import (
    OdetteConnectorRecordSimpleExpression,
    OdetteConnectorRecordSimpleExpressionOperator,
)
from .odette_connector_record_grouping_expression import (
    OdetteConnectorRecordGroupingExpression,
    OdetteConnectorRecordGroupingExpressionOperator,
)
from .odette_connector_record import OdetteConnectorRecord
from .oftp2_connector_record_expression import Oftp2ConnectorRecordExpression
from .oftp2_connector_record_simple_expression import (
    Oftp2ConnectorRecordSimpleExpression,
    Oftp2ConnectorRecordSimpleExpressionOperator,
    Oftp2ConnectorRecordSimpleExpressionProperty,
)
from .oftp2_connector_record_grouping_expression import (
    Oftp2ConnectorRecordGroupingExpression,
    Oftp2ConnectorRecordGroupingExpressionOperator,
)
from .oftp2_connector_record import Oftp2ConnectorRecord
from .packaged_component_expression import PackagedComponentExpression
from .packaged_component_simple_expression import (
    PackagedComponentSimpleExpression,
    PackagedComponentSimpleExpressionOperator,
)
from .packaged_component_grouping_expression import (
    PackagedComponentGroupingExpression,
    PackagedComponentGroupingExpressionOperator,
)
from .component_info import ComponentInfo
from .process_integration_pack_info import ProcessIntegrationPackInfo
from .process_expression import ProcessExpression
from .process_simple_expression import (
    ProcessSimpleExpression,
    ProcessSimpleExpressionOperator,
    ProcessSimpleExpressionProperty,
)
from .process_grouping_expression import (
    ProcessGroupingExpression,
    ProcessGroupingExpressionOperator,
)
from .process_atom_attachment_expression import ProcessAtomAttachmentExpression
from .process_atom_attachment_simple_expression import (
    ProcessAtomAttachmentSimpleExpression,
    ProcessAtomAttachmentSimpleExpressionOperator,
    ProcessAtomAttachmentSimpleExpressionProperty,
)
from .process_atom_attachment_grouping_expression import (
    ProcessAtomAttachmentGroupingExpression,
    ProcessAtomAttachmentGroupingExpressionOperator,
)
from .process_schedule_status_expression import ProcessScheduleStatusExpression
from .process_schedule_status_simple_expression import (
    ProcessScheduleStatusSimpleExpression,
    ProcessScheduleStatusSimpleExpressionOperator,
    ProcessScheduleStatusSimpleExpressionProperty,
)
from .process_schedule_status_grouping_expression import (
    ProcessScheduleStatusGroupingExpression,
    ProcessScheduleStatusGroupingExpressionOperator,
)
from .schedule_retry import ScheduleRetry
from .schedule import Schedule
from .process_schedules_expression import ProcessSchedulesExpression
from .process_schedules_simple_expression import (
    ProcessSchedulesSimpleExpression,
    ProcessSchedulesSimpleExpressionOperator,
    ProcessSchedulesSimpleExpressionProperty,
)
from .process_schedules_grouping_expression import (
    ProcessSchedulesGroupingExpression,
    ProcessSchedulesGroupingExpressionOperator,
)
from .all_documents import AllDocuments, DocumentStatus
from .selected_documents import SelectedDocuments
from .document import Document
from .role_expression import RoleExpression
from .role_simple_expression import (
    RoleSimpleExpression,
    RoleSimpleExpressionOperator,
    RoleSimpleExpressionProperty,
)
from .role_grouping_expression import (
    RoleGroupingExpression,
    RoleGroupingExpressionOperator,
)
from .rosetta_net_connector_record_expression import RosettaNetConnectorRecordExpression
from .rosetta_net_connector_record_simple_expression import (
    RosettaNetConnectorRecordSimpleExpression,
    RosettaNetConnectorRecordSimpleExpressionOperator,
    RosettaNetConnectorRecordSimpleExpressionProperty,
)
from .rosetta_net_connector_record_grouping_expression import (
    RosettaNetConnectorRecordGroupingExpression,
    RosettaNetConnectorRecordGroupingExpressionOperator,
)
from .rosetta_net_connector_record import RosettaNetConnectorRecord
from .shared_web_server_cloud_tennant_general import SharedWebServerCloudTennantGeneral
from .shared_web_server_cors import SharedWebServerCors
from .shared_web_server_general import SharedWebServerGeneral
from .shared_web_server_user_management import SharedWebServerUserManagement
from .listener_port_configuration import ListenerPortConfiguration
from .shared_web_server_port import SharedWebServerPort
from .shared_web_server_cors_origin import SharedWebServerCorsOrigin
from .shared_web_server_authentication import SharedWebServerAuthentication
from .shared_web_server_protected_headers import SharedWebServerProtectedHeaders
from .shared_web_server_login_module_configuration import (
    SharedWebServerLoginModuleConfiguration,
)
from .shared_web_server_login_module_option import SharedWebServerLoginModuleOption
from .shared_web_server_user import SharedWebServerUser
from .throughput_account_expression import ThroughputAccountExpression
from .throughput_account_simple_expression import (
    ThroughputAccountSimpleExpression,
    ThroughputAccountSimpleExpressionOperator,
    ThroughputAccountSimpleExpressionProperty,
)
from .throughput_account_grouping_expression import (
    ThroughputAccountGroupingExpression,
    ThroughputAccountGroupingExpressionOperator,
)
from .throughput_account import ThroughputAccount
from .throughput_account_group_expression import ThroughputAccountGroupExpression
from .throughput_account_group_simple_expression import (
    ThroughputAccountGroupSimpleExpression,
    ThroughputAccountGroupSimpleExpressionOperator,
    ThroughputAccountGroupSimpleExpressionProperty,
)
from .throughput_account_group_grouping_expression import (
    ThroughputAccountGroupGroupingExpression,
    ThroughputAccountGroupGroupingExpressionOperator,
)
from .tradacoms_connector_record_expression import TradacomsConnectorRecordExpression
from .tradacoms_connector_record_simple_expression import (
    TradacomsConnectorRecordSimpleExpression,
    TradacomsConnectorRecordSimpleExpressionOperator,
    TradacomsConnectorRecordSimpleExpressionProperty,
)
from .tradacoms_connector_record_grouping_expression import (
    TradacomsConnectorRecordGroupingExpression,
    TradacomsConnectorRecordGroupingExpressionOperator,
)
from .tradacoms_connector_record import TradacomsConnectorRecord
from .contact_info import ContactInfo
from .partner_communication import PartnerCommunication
from .partner_document_types import PartnerDocumentTypes
from .partner_info import PartnerInfo
from .as2_communication_options import (
    As2CommunicationOptions,
    As2CommunicationOptionsCommunicationSetting,
)
from .disk_communication_options import (
    DiskCommunicationOptions,
    DiskCommunicationOptionsCommunicationSetting,
)
from .ftp_communication_options import (
    FtpCommunicationOptions,
    FtpCommunicationOptionsCommunicationSetting,
)
from .http_communication_options import (
    HttpCommunicationOptions,
    HttpCommunicationOptionsCommunicationSetting,
)
from .mllp_communication_options import MllpCommunicationOptions
from .oftp_communication_options import (
    OftpCommunicationOptions,
    OftpCommunicationOptionsCommunicationSetting,
)
from .sftp_communication_options import (
    SftpCommunicationOptions,
    SftpCommunicationOptionsCommunicationSetting,
)
from .as2_send_settings import As2SendSettings, As2SendSettingsAuthenticationType
from .as2_receive_options import As2ReceiveOptions
from .as2_send_options import As2SendOptions
from .shared_communication_channel import SharedCommunicationChannel
from .as2_basic_auth_info import As2BasicAuthInfo
from .private_certificate import PrivateCertificate
from .public_certificate import PublicCertificate
from .as2_partner_info import As2PartnerInfo
from .as2_mdn_options import As2MdnOptions, MdnDigestAlg, Synchronous
from .as2_message_options import (
    As2MessageOptions,
    AttachmentOption,
    DataContentType,
    As2MessageOptionsEncryptionAlgorithm,
    SigningDigestAlg,
)
from .as2_my_company_info import As2MyCompanyInfo
from .attachment_info import AttachmentInfo, AttachmentContentType
from .disk_get_options import DiskGetOptions, FilterMatchType
from .disk_send_options import DiskSendOptions, WriteOption
from .ftp_get_options import (
    FtpGetOptions,
    FtpGetOptionsFtpAction,
    FtpGetOptionsTransferType,
)
from .ftp_send_options import (
    FtpSendOptions,
    FtpSendOptionsFtpAction,
    FtpSendOptionsTransferType,
)
from .ftp_settings import FtpSettings, ConnectionMode
from .ftpssl_options import FtpsslOptions, Sslmode
from .http_get_options import (
    HttpGetOptions,
    HttpGetOptionsMethodType,
    HttpGetOptionsRequestProfileType,
    HttpGetOptionsResponseProfileType,
)
from .http_listen_options import HttpListenOptions
from .http_send_options import (
    HttpSendOptions,
    HttpSendOptionsMethodType,
    HttpSendOptionsRequestProfileType,
    HttpSendOptionsResponseProfileType,
)
from .http_settings import HttpSettings, HttpSettingsAuthenticationType, CookieScope
from .http_path_elements import HttpPathElements
from .http_reflect_headers import HttpReflectHeaders
from .http_request_headers import HttpRequestHeaders
from .http_response_header_mapping import HttpResponseHeaderMapping
from .element import Element
from .header import Header
from .http_auth_settings import HttpAuthSettings
from .httpo_auth2_settings import HttpoAuth2Settings, GrantType
from .httpo_auth_settings import HttpoAuthSettings, SignatureMethod
from .httpssl_options import HttpsslOptions
from .http_endpoint import HttpEndpoint
from .http_request_parameters import HttpRequestParameters
from .httpo_auth_credentials import HttpoAuthCredentials
from .parameter import Parameter
from .mllp_send_settings import MllpSendSettings
from .mllpssl_options import MllpsslOptions
from .edi_delimiter import EdiDelimiter, DelimiterValue
from .oftp_connection_settings import OftpConnectionSettings
from .oftp_get_options import OftpGetOptions
from .oftp_send_options import OftpSendOptions
from .oftp_listen_options import OftpListenOptions
from .default_oftp_connection_settings import DefaultOftpConnectionSettings
from .oftp_partner_info import OftpPartnerInfo
from .oftp_partner_group_type import OftpPartnerGroupType
from .oftp_local_info import OftpLocalInfo
from .oftp_send_options_info import OftpSendOptionsInfo
from .default_oftp_partner_send_settings import DefaultOftpPartnerSendSettings
from .oftp_listen_options_info import OftpListenOptionsInfo
from .sftp_get_options import SftpGetOptions, SftpGetOptionsFtpAction
from .sftp_send_options import SftpSendOptions, SftpSendOptionsFtpAction
from .sftp_settings import SftpSettings
from .sftp_proxy_settings import SftpProxySettings, SftpProxySettingsType
from .sftpssh_options import SftpsshOptions
from .partner_document_type import PartnerDocumentType, InvalidDocumentRouting
from .edifact_partner_info import EdifactPartnerInfo
from .hl7_partner_info import Hl7PartnerInfo
from .odette_partner_info import OdettePartnerInfo
from .rosetta_net_partner_info import RosettaNetPartnerInfo
from .tradacoms_partner_info import TradacomsPartnerInfo
from .x12_partner_info import X12PartnerInfo
from .edifact_control_info import EdifactControlInfo
from .edifact_options import (
    EdifactOptions,
    EdifactOptionsAcknowledgementoption,
    EdifactOptionsEnvelopeoption,
    EdifactOptionsOutboundValidationOption,
)
from .unb_control_info import (
    UnbControlInfo,
    UnbControlInfoInterchangeIdQual,
    UnbControlInfoPriority,
    UnbControlInfoReferencePasswordQualifier,
    UnbControlInfoSyntaxId,
    UnbControlInfoSyntaxVersion,
    UnbControlInfoTestIndicator,
)
from .ung_control_info import UngControlInfo, ApplicationIdQual
from .unh_control_info import (
    UnhControlInfo,
    UnhControlInfoControllingAgency,
    UnhControlInfoRelease,
    UnhControlInfoVersion,
)
from .edi_segment_terminator import EdiSegmentTerminator, SegmentTerminatorValue
from .hl7_control_info import Hl7ControlInfo
from .hl7_options import (
    Hl7Options,
    Acceptackoption,
    Appackoption,
    Batchoption,
    Hl7OptionsOutboundValidationOption,
)
from .msh_control_info import MshControlInfo
from .hd_type import HdType
from .processing_type import ProcessingType, ProcessingId, ProcessingMode
from .odette_control_info import OdetteControlInfo
from .odette_options import (
    OdetteOptions,
    OdetteOptionsAcknowledgementoption,
    OdetteOptionsEnvelopeoption,
    OdetteOptionsOutboundValidationOption,
)
from .odette_unb_control_info import (
    OdetteUnbControlInfo,
    OdetteUnbControlInfoInterchangeIdQual,
    OdetteUnbControlInfoPriority,
    OdetteUnbControlInfoReferencePasswordQualifier,
    OdetteUnbControlInfoSyntaxId,
    OdetteUnbControlInfoSyntaxVersion,
    OdetteUnbControlInfoTestIndicator,
)
from .odette_unh_control_info import (
    OdetteUnhControlInfo,
    OdetteUnhControlInfoControllingAgency,
    OdetteUnhControlInfoRelease,
    OdetteUnhControlInfoVersion,
)
from .rosetta_net_control_info import (
    RosettaNetControlInfo,
    GlobalUsageCode,
    PartnerIdType,
)
from .rosetta_net_message_options import (
    RosettaNetMessageOptions,
    ContentTransferEncoding,
    RosettaNetMessageOptionsEncryptionAlgorithm,
    SignatureDigestAlgorithm,
)
from .rosetta_net_options import RosettaNetOptions, RosettaNetOptionsVersion
from .tradacoms_control_info import TradacomsControlInfo
from .tradacoms_options import TradacomsOptions
from .stx_control_info import StxControlInfo
from .x12_control_info import X12ControlInfo
from .x12_options import (
    X12Options,
    X12OptionsAcknowledgementoption,
    X12OptionsEnvelopeoption,
    X12OptionsOutboundValidationOption,
)
from .gs_control_info import GsControlInfo, Respagencycode
from .isa_control_info import (
    IsaControlInfo,
    AuthorizationInformationQualifier,
    InterchangeIdQualifier,
    SecurityInformationQualifier,
    Testindicator,
)
from .trading_partner_component_expression import TradingPartnerComponentExpression
from .trading_partner_component_simple_expression import (
    TradingPartnerComponentSimpleExpression,
    TradingPartnerComponentSimpleExpressionOperator,
    TradingPartnerComponentSimpleExpressionProperty,
)
from .trading_partner_component_grouping_expression import (
    TradingPartnerComponentGroupingExpression,
    TradingPartnerComponentGroupingExpressionOperator,
)
from .processing_group_default_routing import ProcessingGroupDefaultRouting
from .processing_group_document_based_routing import ProcessingGroupDocumentBasedRouting
from .processing_group_partner_based_routing import ProcessingGroupPartnerBasedRouting
from .processing_group_trading_partners import ProcessingGroupTradingPartners
from .processing_group_document_standard_route import (
    ProcessingGroupDocumentStandardRoute,
    ProcessingGroupDocumentStandardRouteStandard,
)
from .processing_group_document_type_route import ProcessingGroupDocumentTypeRoute
from .processing_group_document_partner_route import ProcessingGroupDocumentPartnerRoute
from .processing_group_partner_route import ProcessingGroupPartnerRoute
from .processing_group_partner_standard_route import (
    ProcessingGroupPartnerStandardRoute,
    ProcessingGroupPartnerStandardRouteStandard,
)
from .processing_group_partner_document_route import ProcessingGroupPartnerDocumentRoute
from .processing_group_trading_partner import ProcessingGroupTradingPartner
from .trading_partner_processing_group_expression import (
    TradingPartnerProcessingGroupExpression,
)
from .trading_partner_processing_group_simple_expression import (
    TradingPartnerProcessingGroupSimpleExpression,
    TradingPartnerProcessingGroupSimpleExpressionOperator,
)
from .trading_partner_processing_group_grouping_expression import (
    TradingPartnerProcessingGroupGroupingExpression,
    TradingPartnerProcessingGroupGroupingExpressionOperator,
)
from .x12_connector_record_expression import X12ConnectorRecordExpression
from .x12_connector_record_simple_expression import (
    X12ConnectorRecordSimpleExpression,
    X12ConnectorRecordSimpleExpressionOperator,
    X12ConnectorRecordSimpleExpressionProperty,
)
from .x12_connector_record_grouping_expression import (
    X12ConnectorRecordGroupingExpression,
    X12ConnectorRecordGroupingExpressionOperator,
)
from .x12_connector_record import X12ConnectorRecord
from .atom_disk_space import AtomDiskSpace
from .atom_disk_space_directory import AtomDiskSpaceDirectory
from .list_queues import ListQueues
from .queue_record import QueueRecord
from .topic_subscriber import TopicSubscriber
from .listener_status_expression import ListenerStatusExpression
from .listener_status_simple_expression import (
    ListenerStatusSimpleExpression,
    ListenerStatusSimpleExpressionOperator,
    ListenerStatusSimpleExpressionProperty,
)
from .listener_status_grouping_expression import (
    ListenerStatusGroupingExpression,
    ListenerStatusGroupingExpressionOperator,
)
from .listener_status import ListenerStatus
from .organization_contact_info import OrganizationContactInfo
from .organization_component_expression import OrganizationComponentExpression
from .organization_component_simple_expression import (
    OrganizationComponentSimpleExpression,
    OrganizationComponentSimpleExpressionOperator,
    OrganizationComponentSimpleExpressionProperty,
)
from .organization_component_grouping_expression import (
    OrganizationComponentGroupingExpression,
    OrganizationComponentGroupingExpressionOperator,
)
from .partner_archiving import PartnerArchiving
from .shared_communication_channel_component_expression import (
    SharedCommunicationChannelComponentExpression,
)
from .shared_communication_channel_component_simple_expression import (
    SharedCommunicationChannelComponentSimpleExpression,
    SharedCommunicationChannelComponentSimpleExpressionOperator,
    SharedCommunicationChannelComponentSimpleExpressionProperty,
)
from .shared_communication_channel_component_grouping_expression import (
    SharedCommunicationChannelComponentGroupingExpression,
    SharedCommunicationChannelComponentGroupingExpressionOperator,
)
from .account_group_integration_pack_expression import (
    AccountGroupIntegrationPackExpression,
    AccountGroupIntegrationPackExpressionMetadata,
)
from .publisher_packaged_components import PublisherPackagedComponents
from .publisher_packaged_component import PublisherPackagedComponent
from .publisher_integration_pack_expression import (
    PublisherIntegrationPackExpression,
    PublisherIntegrationPackExpressionMetadata,
)
from .release_packaged_components import ReleasePackagedComponents
from .release_packaged_component import ReleasePackagedComponent
from .runtime_cloud import RuntimeCloud
from .runtime_cloud_bulk_request import (
    RuntimeCloudBulkRequest,
    RuntimeCloudBulkRequestType,
)
from .runtime_cloud_bulk_response import (
    RuntimeCloudBulkResponse,
    RuntimeCloudBulkResponseResponse,
)
from .runtime_cloud_query_config import (
    RuntimeCloudQueryConfig,
    RuntimeCloudQueryConfigQueryFilter,
)
from .runtime_cloud_query_response import RuntimeCloudQueryResponse
from .runtime_cloud_expression import RuntimeCloudExpression
from .runtime_cloud_simple_expression import (
    RuntimeCloudSimpleExpression,
    RuntimeCloudSimpleExpressionOperator,
    RuntimeCloudSimpleExpressionProperty,
)
from .runtime_cloud_grouping_expression import (
    RuntimeCloudGroupingExpression,
    RuntimeCloudGroupingExpressionOperator,
)
from .account_cloud_attachment_summary import AccountCloudAttachmentSummary
from .account_cloud_attachment_summary_bulk_request import (
    AccountCloudAttachmentSummaryBulkRequest,
    AccountCloudAttachmentSummaryBulkRequestType,
)
from .account_cloud_attachment_summary_bulk_response import (
    AccountCloudAttachmentSummaryBulkResponse,
    AccountCloudAttachmentSummaryBulkResponseResponse,
)
from .account_cloud_attachment_summary_query_config import (
    AccountCloudAttachmentSummaryQueryConfig,
    AccountCloudAttachmentSummaryQueryConfigQueryFilter,
)
from .account_cloud_attachment_summary_query_response import (
    AccountCloudAttachmentSummaryQueryResponse,
)
from .account_cloud_attachment_summary_expression import (
    AccountCloudAttachmentSummaryExpression,
)
from .account_cloud_attachment_summary_simple_expression import (
    AccountCloudAttachmentSummarySimpleExpression,
    AccountCloudAttachmentSummarySimpleExpressionOperator,
    AccountCloudAttachmentSummarySimpleExpressionProperty,
)
from .account_cloud_attachment_summary_grouping_expression import (
    AccountCloudAttachmentSummaryGroupingExpression,
    AccountCloudAttachmentSummaryGroupingExpressionOperator,
)
from .account_cloud_attachment_properties_default import (
    AccountCloudAttachmentPropertiesDefault,
    As2WorkloadDefault,
    FlowControlParallelProcessTypeOverrideDefault,
    HttpWorkloadDefault,
)
from .account_cloud_attachment_properties_default_async_response import (
    AccountCloudAttachmentPropertiesDefaultAsyncResponse,
)
from .standard_properties import (
    StandardProperties,
    ClusterNetworkTransportType,
    DebugLogLevelThreshold,
    ExecuteProcessesAsForkedJvms,
    ListenerStartupMode,
    SecurityPolicy,
    StandardErrorLogLevel,
)
from .system_properties import SystemProperties
from .custom_runtime_properties import CustomRuntimeProperties
from .custom_system_properties import CustomSystemProperties
from .runtime_properties import RuntimeProperties
from .runtime_properties_async_response import RuntimePropertiesAsyncResponse
from .observability_authentication_fields import ObservabilityAuthenticationFields
from .observability_endpoint_authentication import (
    ObservabilityEndpointAuthentication,
    AuthType,
)
from .observability_endpoint import ObservabilityEndpoint
from .general_settings import GeneralSettings
from .log_settings import LogSettings
from .metric_settings import MetricSettings
from .trace_settings import TraceSettings
from .runtime_observability_settings import RuntimeObservabilitySettings
from .runtime_observability_settings_request import RuntimeObservabilitySettingsRequest
from .runtime_observability_settings_async_response import (
    RuntimeObservabilitySettingsAsyncResponse,
)
from .cloud_attachment_gcp_service_account_config import (
    CloudAttachmentGcpServiceAccountConfig,
)
from .cloud_attachment_gcp_user_account_config import (
    CloudAttachmentGcpUserAccountConfig,
)
from .cloud_attachment_aws_secrets_config import CloudAttachmentAwsSecretsConfig
from .cloud_attachment_azure_secrets_config import CloudAttachmentAzureSecretsConfig
from .cloud_attachment_gcp_secrets_config import CloudAttachmentGcpSecretsConfig
from .cloud_attachment_secrets_manager_provider import (
    CloudAttachmentSecretsManagerProvider,
)
from .cloud_attachment_secrets_configuration_request import (
    CloudAttachmentSecretsConfigurationRequest,
)
from .cloud_attachment_secrets_configuration_response import (
    CloudAttachmentSecretsConfigurationResponse,
)
from .custom_control_info import CustomControlInfo
from .custom_options import CustomOptions, OutboundValidationOptionCustom
from .custom_partner_info import CustomPartnerInfo
from .cloud_managed_secret_config import (
    CloudManagedSecretConfig,
    SecretsManagerType,
)




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"account_id": "accountId", "atom_id": "atomId", "date_": "date"})
class DocumentCountAccount(BaseModel):
    """DocumentCountAccount

    :param account_id: The ID of the account that processed the documents., defaults to None
    :type account_id: str, optional
    :param atom_id: The ID of the Runtime that processed the documents., defaults to None
    :type atom_id: str, optional
    :param date_: The processing date of the documents. The time zone is UTC±00:00., defaults to None
    :type date_: str, optional
    :param value: The count of processed documents., defaults to None
    :type value: int, optional
    """

    def __init__(
        self,
        account_id: str = SENTINEL,
        atom_id: str = SENTINEL,
        date_: str = SENTINEL,
        value: int = SENTINEL,
        **kwargs
    ):
        """DocumentCountAccount

        :param account_id: The ID of the account that processed the documents., defaults to None
        :type account_id: str, optional
        :param atom_id: The ID of the Runtime that processed the documents., defaults to None
        :type atom_id: str, optional
        :param date_: The processing date of the documents. The time zone is UTC±00:00., defaults to None
        :type date_: str, optional
        :param value: The count of processed documents., defaults to None
        :type value: int, optional
        """
        if account_id is not SENTINEL:
            self.account_id = account_id
        if atom_id is not SENTINEL:
            self.atom_id = atom_id
        if date_ is not SENTINEL:
            self.date_ = date_
        if value is not SENTINEL:
            self.value = value
        self._kwargs = kwargs




from typing import Generator, Optional
from .handlers.base_handler import BaseHandler
from ..transport.request import Request
from ..transport.response import Response


class RequestChain:
    """
    Class representing a chain of request handlers.
    Handlers are added to the chain and the request is passed through each handler in the order they were added.

    :ivar Optional[BaseHandler] _head: The first handler in the chain.
    :ivar Optional[BaseHandler] _tail: The last handler in the chain.
    """

    def __init__(self):
        """
        Initialize a new instance of RequestChain.
        """
        self._head: Optional[BaseHandler] = None
        self._tail: Optional[BaseHandler] = None

    def add_handler(self, handler: BaseHandler) -> "RequestChain":
        """
        Add a handler to the chain.

        :param BaseHandler handler: The handler to add.
        :return: The current instance of RequestChain to allow for method chaining.
        :rtype: RequestChain
        """
        if self._head is None:
            self._head = handler
            self._tail = handler
        else:
            self._tail.set_next(handler)
            self._tail = handler

        return self

    def send(self, request: Request) -> Response:
        """
        Send the request through the chain of handlers.

        :param Request request: The request to send.
        :return: The response from the request.
        :rtype: Response
        :raises RuntimeError: If the RequestChain is empty.
        """
        if self._head is not None:
            response, error = self._head.handle(request)

            if error is not None:
                raise error

            return response
        else:
            raise RuntimeError("RequestChain is empty")

    def stream(self, request: Request) -> Generator[Response, None, None]:
        """
        Send the request through the chain of handlers.

        :param Request request: The request to send.
        :return: The response from the request.
        :rtype: Generator[Response, None, None]
        :raises RuntimeError: If the RequestChain is empty.
        """
        if self._head is not None:
            stream = self._head.stream(request)
            for response, error in stream:
                if error is not None:
                    raise error

                yield response
        else:
            raise RuntimeError("RequestChain is empty")




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .account_group_integration_pack_expression import (
    AccountGroupIntegrationPackExpression,
)


@JsonMap({})
class AccountGroupIntegrationPackQueryConfigQueryFilter(BaseModel):
    """AccountGroupIntegrationPackQueryConfigQueryFilter

    :param expression: expression
    :type expression: AccountGroupIntegrationPackExpression
    """

    def __init__(self, expression: AccountGroupIntegrationPackExpression, **kwargs):
        """AccountGroupIntegrationPackQueryConfigQueryFilter

        :param expression: expression
        :type expression: AccountGroupIntegrationPackExpression
        """
        self.expression = self._define_object(
            expression, AccountGroupIntegrationPackExpression
        )
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class AccountGroupIntegrationPackQueryConfig(BaseModel):
    """AccountGroupIntegrationPackQueryConfig

    :param query_filter: query_filter
    :type query_filter: AccountGroupIntegrationPackQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: AccountGroupIntegrationPackQueryConfigQueryFilter, **kwargs
    ):
        """AccountGroupIntegrationPackQueryConfig

        :param query_filter: query_filter
        :type query_filter: AccountGroupIntegrationPackQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, AccountGroupIntegrationPackQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..execution_connector import ExecutionConnectorService
from ...models import ExecutionConnectorQueryResponse, ExecutionConnectorQueryConfig


class ExecutionConnectorServiceAsync(ExecutionConnectorService):
    """
    Async Wrapper for ExecutionConnectorServiceAsync
    """

    def query_execution_connector(
        self, request_body: ExecutionConnectorQueryConfig = None
    ) -> Awaitable[Union[ExecutionConnectorQueryResponse, str]]:
        return to_async(super().query_execution_connector)(request_body)

    def query_more_execution_connector(
        self, request_body: str
    ) -> Awaitable[Union[ExecutionConnectorQueryResponse, str]]:
        return to_async(super().query_more_execution_connector)(request_body)




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .simple_lookup_table_rows import SimpleLookupTableRows


@JsonMap({"rows": "Rows"})
class SimpleLookupTable(BaseModel):
    """SimpleLookupTable

    :param rows: rows
    :type rows: SimpleLookupTableRows
    """

    def __init__(self, rows: SimpleLookupTableRows, **kwargs):
        """SimpleLookupTable

        :param rows: rows
        :type rows: SimpleLookupTableRows
        """
        self.rows = self._define_object(rows, SimpleLookupTableRows)
        self._kwargs = kwargs




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"is_set": "isSet"})
class EncryptedValue(BaseModel):
    """EncryptedValue

    :param is_set: is_set, defaults to None
    :type is_set: bool, optional
    :param path: path, defaults to None
    :type path: str, optional
    """

    def __init__(self, is_set: bool = SENTINEL, path: str = SENTINEL, **kwargs):
        """EncryptedValue

        :param is_set: is_set, defaults to None
        :type is_set: bool, optional
        :param path: path, defaults to None
        :type path: str, optional
        """
        if is_set is not SENTINEL:
            self.is_set = is_set
        if path is not SENTINEL:
            self.path = path
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .component_environment_attachment_expression import (
    ComponentEnvironmentAttachmentExpression,
    ComponentEnvironmentAttachmentExpressionGuard,
)
from .component_environment_attachment_simple_expression import (
    ComponentEnvironmentAttachmentSimpleExpression,
)
from .component_environment_attachment_grouping_expression import (
    ComponentEnvironmentAttachmentGroupingExpression,
)


@JsonMap({})
class ComponentEnvironmentAttachmentQueryConfigQueryFilter(BaseModel):
    """ComponentEnvironmentAttachmentQueryConfigQueryFilter

    :param expression: expression
    :type expression: ComponentEnvironmentAttachmentExpression
    """

    def __init__(self, expression: ComponentEnvironmentAttachmentExpression, **kwargs):
        """ComponentEnvironmentAttachmentQueryConfigQueryFilter

        :param expression: expression
        :type expression: ComponentEnvironmentAttachmentExpression
        """
        self.expression = ComponentEnvironmentAttachmentExpressionGuard.return_one_of(
            expression
        )
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class ComponentEnvironmentAttachmentQueryConfig(BaseModel):
    """ComponentEnvironmentAttachmentQueryConfig

    :param query_filter: query_filter
    :type query_filter: ComponentEnvironmentAttachmentQueryConfigQueryFilter
    """

    def __init__(
        self,
        query_filter: ComponentEnvironmentAttachmentQueryConfigQueryFilter,
        **kwargs,
    ):
        """ComponentEnvironmentAttachmentQueryConfig

        :param query_filter: query_filter
        :type query_filter: ComponentEnvironmentAttachmentQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, ComponentEnvironmentAttachmentQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..persisted_process_properties import PersistedProcessPropertiesService
from ...models import (
    PersistedProcessProperties,
    AsyncOperationTokenResult,
    PersistedProcessPropertiesAsyncResponse
)


class PersistedProcessPropertiesServiceAsync(PersistedProcessPropertiesService):
    """
    Async Wrapper for PersistedProcessPropertiesServiceAsync
    """

    def update_persisted_process_properties(
        self, id_: str, request_body: PersistedProcessProperties = None
    ) -> Awaitable[Union[PersistedProcessProperties, str]]:
        return to_async(super().update_persisted_process_properties)(id_, request_body)

    def async_get_persisted_process_properties(
        self, id_: str
    ) -> Awaitable[Union[AsyncOperationTokenResult, str]]:
        return to_async(super().async_get_persisted_process_properties)(id_)

    def async_token_persisted_process_properties(
        self, token: str
    ) -> Awaitable[Union[PersistedProcessPropertiesAsyncResponse, str]]:
        return to_async(super().async_token_persisted_process_properties)(token)




from typing import Union, Any
from xml.etree import ElementTree as ET
from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..net.transport.api_error import ApiError
from ..net.environment.environment import Environment
from ..models.utils.cast_models import cast_models
from ..models import Component, ComponentBulkRequest, ComponentBulkResponse
from ..net.transport.utils import parse_xml_to_dict, parse_xml_to_dict_with_preservation


class ComponentService(BaseService):

    @cast_models
    def create_component(self, request_body: str = None) -> Union[Component, str]:
        """- Cannot create components for types not eligible for your account. For example, if your account does not have the B2B/EDI feature, you will not be able to create Trading Partner components.
         - Request will not be processed in case if the payload has invalid attributes and tags under the <object> section.
         - Include the `branchId` in the request body to specify a branch on which you want to create the component.
         - >**Note:** To create or update a component, you must supply a valid component XML format for the given type.

         The component XML can be rather complex with many optional fields and nested configuration. For this reason we strongly recommend approaching it by first creating the desired component structure/skeleton as you would normally in the Build page UI, then exporting the XML using the Component object GET. This will provide an accurate example or template of the XML you will need to create. You can replace values or continue that pattern as you need for your use case.

        :param request_body: The request body., defaults to None
        :type request_body: str, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[Component, str]
        """

        Validator(str).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Component",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body, "application/xml")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return Component._unmap(response)
        if content == "application/xml":
            return Component._unmap(parse_xml_to_dict(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def get_component(self, component_id: str) -> Union[Component, str]:
        """- When using the GET operation by componentId, it returns the latest component if you do not provide the version.
         - When you provide the version in the format of `<componentId>` ~ `<version>`, it returns the specific version of the component.
         - The GET operation only accepts mediaType `application/xml` for the API response.
         - The limit is 5 requests for the BULK GET operation. All other API objects have a limit of 100 BULK GET requests.
         - If you want information for a component on a specific branch, include the branchId in the GET request:   `https://api.boomi.com/api/rest/v1/{accountId}/Component/{componentId}~{branchId}`

        :param component_id: The ID of the component. The component ID is available on the Revision History dialog, which you can access from the Build page in the service. This must be omitted for the CREATE operation but it is required for the UPDATE operation.
        :type component_id: str
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: The parsed response data.
        :rtype: Union[Component, str]
        """

        Validator(str).validate(component_id)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Component/{{componentId}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("componentId", component_id)
            .serialize()
            .set_method("GET")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return Component._unmap(response)
        if content == "application/xml":
            # Phase 2: Use XML preservation parsing for Component objects
            return Component._unmap(parse_xml_to_dict_with_preservation(response))
        raise ApiError("Error on deserializing the response.", status, response)

    @cast_models
    def update_component(
        self, component_id: str, request_body: Any = None
    ) -> Union[Component, str]:
        """- Full updates only. No partial updates. If part of the object's configuration is omitted, the component will be updated without that configuration.
           - The only exception is for encrypted fields such as passwords. Omitting an encrypted field from the update request will NOT impact the saved value.
         - Requests without material changes to configuration will be rejected to prevent unnecessary revisions.
         - Request will not be processed in case if the payload has invalid attributes and tags under the `<object>` section.
         - For the saved process property components, modifications to the data type are not permitted.
         - Include the `branchId` in the request body to specify the branch on which you want to update the component.
         - >**Note:** To create or update a component, you must supply a valid component XML format for the given type.

        Phase 2 Enhancement: This method now accepts Component objects in addition to XML strings.
        When a Component object is passed, it automatically converts to XML using the to_xml() method
        which preserves the original XML structure.

        :param request_body: Component object or XML string. Can be Component, str, or None.
        :type request_body: Union[Component, str, None]
        :param component_id: The ID of the component.
        :type component_id: str
        :return: The parsed response data.
        :rtype: Union[Component, str]
        """
        import warnings
        
        Validator(str).validate(component_id)
        
        # Phase 2: Handle different types of request_body
        xml_body = None
        
        if request_body is None:
            raise ValueError("request_body is required for component updates")
        elif isinstance(request_body, str):
            # Traditional XML string
            xml_body = request_body
        elif hasattr(request_body, 'to_xml'):
            # Component object with to_xml method
            xml_body = request_body.to_xml()
        elif hasattr(request_body, 'object') and isinstance(getattr(request_body, 'object'), dict):
            # Legacy Component object with dict-based object field
            warnings.warn(
                "Updating components with dict-based object is deprecated and may fail. "
                "Use Component objects with XML preservation or raw XML strings.",
                DeprecationWarning,
                stacklevel=2
            )
            # Fall back to trying to serialize as XML (this may still fail)
            xml_body = str(request_body)  # This won't work well, but provides backward compatibility attempt
        else:
            # Try to convert whatever it is to string
            xml_body = str(request_body)
        
        # Validate we have XML content
        if not xml_body or not xml_body.strip():
            raise ValueError("No valid XML content found in request_body")

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Component/{{componentId}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("componentId", component_id)
            .serialize()
            .set_method("POST")
            .set_body(xml_body, "application/xml")
        )

        response, status, content = self.send_request(serialized_request)
        if content == "application/json":
            return Component._unmap(response)
        if content == "application/xml":
            # Phase 2: Use XML preservation parsing for response too
            return Component._unmap(parse_xml_to_dict_with_preservation(response))
        raise ApiError("Error on deserializing the response.", status, response)

    def bulk_component_raw(self, request_body: ComponentBulkRequest = None) -> str:
        """Get multiple components as raw XML string.
        
        The limit for the BULK GET operation is 5 requests. This method returns
        the raw XML response from the API without any parsing.

        :param request_body: The request body., defaults to None
        :type request_body: ComponentBulkRequest, optional
        :return: Raw XML response from the API
        :rtype: str
        """
        Validator(ComponentBulkRequest).is_optional().validate(request_body)

        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Component/bulk",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response, status, content = self.send_request(serialized_request)
        if status >= 200 and status < 300:
            return response  # Return raw XML string
        raise ApiError(f"Failed to bulk get components: HTTP {status}", status, response)

    @cast_models  
    def bulk_component(self, request_body: ComponentBulkRequest = None):
        """Get multiple components with proper XML parsing.
        
        The limit for the BULK GET operation is 5 requests. This method properly
        handles the XML response from the API and returns a list of components.

        :param request_body: The request body., defaults to None
        :type request_body: ComponentBulkRequest, optional
        :return: List of Component objects from successful responses
        :rtype: List[Component]
        """
        # Get raw XML response first
        xml_response = self.bulk_component_raw(request_body)
        
        # Parse XML response  
        try:
            root = ET.fromstring(xml_response)
            components = []
            ns = {'bns': 'http://api.platform.boomi.com/'}
            
            # Find all response elements
            for response_elem in root.findall('bns:response', ns):
                status_code = response_elem.get('statusCode', '')
                
                if status_code == '200':
                    # Find the Result element (which is a Component)
                    result_elem = response_elem.find('bns:Result', ns)
                    if result_elem is not None:
                        # Convert the Component XML element to raw XML string
                        component_xml = ET.tostring(result_elem, encoding='unicode')
                        
                        # Parse this single component XML using existing get_component logic
                        # For now, we'll use the raw XML approach to avoid complex parsing
                        components.append(component_xml)
                else:
                    # Handle error responses  
                    error_msg = response_elem.get('errorMessage', 'Unknown error')
                    print(f"⚠️ Component failed with status {status_code}: {error_msg}")
            
            return components
            
        except ET.ParseError as e:
            raise ApiError(f"Failed to parse XML response: {e}", 200, xml_response)

    # ========== Phase 1: Raw XML Support ==========
    # These methods provide direct XML access without any dict conversion
    # This preserves XML structure exactly for complex components
    
    def get_component_raw(self, component_id: str) -> str:
        """Get component as raw XML string without any parsing or conversion.
        
        This method preserves the exact XML structure returned by the API,
        including namespaces, element order, and attributes. Use this when
        you need full control over the XML or when dealing with complex
        components that fail with dict-based approaches.
        
        :param component_id: The ID of the component
        :type component_id: str
        :return: Raw XML string exactly as returned by the API
        :rtype: str
        """
        Validator(str).validate(component_id)
        
        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Component/{{componentId}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("componentId", component_id)
            .serialize()
            .set_method("GET")
        )
        
        # Return raw response without any parsing
        response, status, content = self.send_request(serialized_request)
        if status >= 200 and status < 300:
            return response  # Return raw XML string
        raise ApiError(f"Failed to get component: HTTP {status}", status, response)
    
    def update_component_raw(self, component_id: str, xml: str) -> str:
        """Update component with raw XML string.
        
        This method sends the XML directly to the API without any conversion,
        preserving the exact structure you provide. Use this when you need
        full control over the XML or when dealing with complex components.
        
        :param component_id: The ID of the component
        :type component_id: str
        :param xml: Raw XML string to send to the API
        :type xml: str
        :return: Raw XML response from the API
        :rtype: str
        """
        Validator(str).validate(component_id)
        Validator(str).validate(xml)
        
        serialized_request = (
            Serializer(
                f"{self.base_url or Environment.DEFAULT.url}/Component/{{componentId}}",
                [self.get_access_token(), self.get_basic_auth()],
            )
            .add_path("componentId", component_id)
            .serialize()
            .set_method("POST")
            .set_body(xml, "application/xml")
        )
        
        response, status, content = self.send_request(serialized_request)
        if status >= 200 and status < 300:
            return response  # Return raw XML response
        raise ApiError(f"Failed to update component: HTTP {status}", status, response)
    
    def get_component_etree(self, component_id: str) -> ET.Element:
        """Get component as ElementTree for DOM manipulation.
        
        This method returns an ElementTree Element that you can manipulate
        using standard XML DOM methods while preserving structure.
        
        :param component_id: The ID of the component
        :type component_id: str
        :return: ElementTree Element root
        :rtype: xml.etree.ElementTree.Element
        """
        xml = self.get_component_raw(component_id)
        root = ET.fromstring(xml)
        
        # Register namespaces to preserve them on serialization
        ns = self._get_default_namespace(root)
        if ns:
            ET.register_namespace("", ns)  # Register default namespace
        
        # Also register bns namespace
        ET.register_namespace("bns", "http://api.platform.boomi.com/")
        
        return root
    
    def update_component_etree(self, component_id: str, element: ET.Element) -> str:
        """Update component from ElementTree Element.
        
        This method serializes the ElementTree back to XML and sends it to
        the API, preserving the structure of your DOM manipulations.
        
        :param component_id: The ID of the component
        :type component_id: str
        :param element: ElementTree Element to serialize and send
        :type element: xml.etree.ElementTree.Element
        :return: Raw XML response from the API
        :rtype: str
        """
        # Ensure namespaces are registered
        ns = self._get_default_namespace(element)
        if ns:
            ET.register_namespace("", ns)
        ET.register_namespace("bns", "http://api.platform.boomi.com/")
        
        # Convert Element to XML string
        xml = ET.tostring(element, encoding='unicode', xml_declaration=True)
        
        # Update using raw XML method
        return self.update_component_raw(component_id, xml)
    
    @staticmethod
    def _get_default_namespace(element: ET.Element) -> str:
        """Extract default namespace from an element.
        
        :param element: ElementTree Element
        :return: Default namespace URI or None
        """
        tag = element.tag
        if tag.startswith("{") and "}" in tag:
            return tag[1:tag.index("}")]
        return None




from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


@JsonMap({"id_": "id"})
class MapExtensionsUserDefinedFunction(BaseModel):
    """MapExtensionsUserDefinedFunction

    :param id_: id_, defaults to None
    :type id_: str, optional
    :param version: version, defaults to None
    :type version: int, optional
    """

    def __init__(self, id_: str = SENTINEL, version: int = SENTINEL, **kwargs):
        """MapExtensionsUserDefinedFunction

        :param id_: id_, defaults to None
        :type id_: str, optional
        :param version: version, defaults to None
        :type version: int, optional
        """
        if id_ is not SENTINEL:
            self.id_ = id_
        if version is not SENTINEL:
            self.version = version
        self._kwargs = kwargs




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .deployed_process import DeployedProcess


@JsonMap({"process": "Process", "atom_id": "atomId"})
class PersistedProcessProperties(BaseModel):
    """PersistedProcessProperties

    :param process: process, defaults to None
    :type process: List[DeployedProcess], optional
    :param atom_id: A unique ID assigned by the system to the Runtime.
    :type atom_id: str
    """

    def __init__(
        self, atom_id: str, process: List[DeployedProcess] = SENTINEL, **kwargs
    ):
        """PersistedProcessProperties

        :param process: process, defaults to None
        :type process: List[DeployedProcess], optional
        :param atom_id: A unique ID assigned by the system to the Runtime.
        :type atom_id: str
        """
        if process is not SENTINEL:
            self.process = self._define_list(process, DeployedProcess)
        self.atom_id = atom_id
        self._kwargs = kwargs




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class ExecutionType(Enum):
    """An enumeration representing different categories.

    :cvar EXECMANUAL: "exec_manual"
    :vartype EXECMANUAL: str
    :cvar EXECSCHED: "exec_sched"
    :vartype EXECSCHED: str
    :cvar EXECLISTENER: "exec_listener"
    :vartype EXECLISTENER: str
    :cvar EXECLISTENERBRIDGE: "exec_listener_bridge"
    :vartype EXECLISTENERBRIDGE: str
    :cvar EXECREMOTE: "exec_remote"
    :vartype EXECREMOTE: str
    :cvar RETRYMANUAL: "retry_manual"
    :vartype RETRYMANUAL: str
    :cvar RETRYSCHED: "retry_sched"
    :vartype RETRYSCHED: str
    :cvar FIBER: "fiber"
    :vartype FIBER: str
    :cvar SUBPROCESS: "sub_process"
    :vartype SUBPROCESS: str
    :cvar TESTMANUAL: "test_manual"
    :vartype TESTMANUAL: str
    :cvar TESTSUBPROCESS: "test_sub_process"
    :vartype TESTSUBPROCESS: str
    :cvar UNKNOWN: "unknown"
    :vartype UNKNOWN: str
    """

    EXECMANUAL = "exec_manual"
    EXECSCHED = "exec_sched"
    EXECLISTENER = "exec_listener"
    EXECLISTENERBRIDGE = "exec_listener_bridge"
    EXECREMOTE = "exec_remote"
    RETRYMANUAL = "retry_manual"
    RETRYSCHED = "retry_sched"
    FIBER = "fiber"
    SUBPROCESS = "sub_process"
    TESTMANUAL = "test_manual"
    TESTSUBPROCESS = "test_sub_process"
    UNKNOWN = "unknown"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, ExecutionType._member_map_.values()))


@JsonMap(
    {
        "atom_id": "atomId",
        "atom_name": "atomName",
        "execution_duration": "executionDuration",
        "execution_id": "executionId",
        "execution_time": "executionTime",
        "execution_type": "executionType",
        "inbound_document_count": "inboundDocumentCount",
        "inbound_document_size": "inboundDocumentSize",
        "inbound_error_document_count": "inboundErrorDocumentCount",
        "launcher_id": "launcherID",
        "node_id": "nodeId",
        "original_execution_id": "originalExecutionId",
        "outbound_document_count": "outboundDocumentCount",
        "outbound_document_size": "outboundDocumentSize",
        "parent_execution_id": "parentExecutionId",
        "process_id": "processId",
        "process_name": "processName",
        "recorded_date": "recordedDate",
        "report_key": "reportKey",
        "top_level_execution_id": "topLevelExecutionId",
    }
)
class ExecutionRecord(BaseModel):
    """ExecutionRecord

    :param account: The ID of the account in which you ran this execution.
    :type account: str
    :param atom_id: The ID of the Runtime the on which the process ran.
    :type atom_id: str
    :param atom_name: The name of the Runtime on which the process ran.
    :type atom_name: str
    :param execution_duration: The number of milliseconds it took to run the process., defaults to None
    :type execution_duration: int, optional
    :param execution_id: The ID of the execution.
    :type execution_id: str
    :param execution_time: The start date and time this run.
    :type execution_time: str
    :param execution_type: Indicates how initiation of the process run occurred. Possible values are:\<br /\>-   *exec*\_*listener* \(run initiated by a listener request\)\<br /\>- *exec*\_*manual* \(manual run\)\<br /\>- *exec*\_*sched* \(scheduled run\)\<br /\>- *retry*\_*manual* \(manual retry\)\<br /\>- *retry*\_*sched* \(scheduled retry\)\<br /\>- *sub*\_*process* \(subprocess call\)\<br /\>- *test*\_*manual* \(test mode run\)
    :type execution_type: ExecutionType
    :param inbound_document_count: The number of processed inbound documents., defaults to None
    :type inbound_document_count: int, optional
    :param inbound_document_size: The aggregate size in bytes of the processed inbound documents., defaults to None
    :type inbound_document_size: int, optional
    :param inbound_error_document_count: The number of processed inbound documents with errors., defaults to None
    :type inbound_error_document_count: int, optional
    :param launcher_id: The API Service component that kicks off the run.\<br /\>\<br /\> **Note:** The Runtime must have the **API Type** set to **Advanced** on the **Shared Web Server** tab of **Runtime Management** to specify the launcherID.
    :type launcher_id: str
    :param message: Any error message returned from the run.
    :type message: str
    :param node_id: The ID of the Molecule node in which the run occurred for a process run in a Runtime cluster or Runtime cloud. For a run occurring in a Runtime, this field is omitted.
    :type node_id: str
    :param original_execution_id: The original execution ID, if this execution is a retry.
    :type original_execution_id: str
    :param outbound_document_count: The number of processed outbound documents., defaults to None
    :type outbound_document_count: int, optional
    :param outbound_document_size: The aggregate size in bytes of the processed outbound documents., defaults to None
    :type outbound_document_size: int, optional
    :param parent_execution_id: The ID of the run of the parent process, if this run and the parent process’ run were both subprocesses.
    :type parent_execution_id: str
    :param process_id: The ID of the run process.
    :type process_id: str
    :param process_name: The name of the run process.
    :type process_name: str
    :param recorded_date: The end time when the process execution completes.
    :type recorded_date: str
    :param report_key: The web service user that authenticated to make the run request.\<br /\>\<br /\>**Note:** For Runtimes with an Authentication Type of External Provider, the reportKey is the API Key. Otherwise, it is the specified user name.
    :type report_key: str
    :param status: The status of the run. Possible values are:\<br /\>- *ABORTED*\<br /\>- *COMPLETE*\<br /\>- *COMPLETE*\_*WARN*\<br /\>- *DISCARDED*\<br /\>- *ERROR*\<br /\>- *INPROCESS*\<br /\>- *STARTED*
    :type status: str
    :param top_level_execution_id: The ID of the run of the top-level process, if this run is a subprocess.
    :type top_level_execution_id: str
    """

    def __init__(
        self,
        account: str,
        atom_id: str,
        atom_name: str,
        execution_id: str,
        execution_time: str,
        execution_type: ExecutionType,
        process_id: str,
        process_name: str,
        recorded_date: str,
        status: str,
        execution_duration: int = SENTINEL,
        inbound_document_count: int = SENTINEL,
        inbound_document_size: int = SENTINEL,
        inbound_error_document_count: int = SENTINEL,
        launcher_id: str = SENTINEL,
        message: str = SENTINEL,
        node_id: str = SENTINEL,
        original_execution_id: str = SENTINEL,
        outbound_document_count: int = SENTINEL,
        outbound_document_size: int = SENTINEL,
        parent_execution_id: str = SENTINEL,
        report_key: str = SENTINEL,
        top_level_execution_id: str = SENTINEL,
        **kwargs
    ):
        """ExecutionRecord

        :param account: The ID of the account in which you ran this execution.
        :type account: str
        :param atom_id: The ID of the Runtime the on which the process ran.
        :type atom_id: str
        :param atom_name: The name of the Runtime on which the process ran.
        :type atom_name: str
        :param execution_duration: The number of milliseconds it took to run the process., defaults to None
        :type execution_duration: int, optional
        :param execution_id: The ID of the execution.
        :type execution_id: str
        :param execution_time: The start date and time this run.
        :type execution_time: str
        :param execution_type: Indicates how initiation of the process run occurred. Possible values are:\<br /\>-   *exec*\_*listener* \(run initiated by a listener request\)\<br /\>- *exec*\_*manual* \(manual run\)\<br /\>- *exec*\_*sched* \(scheduled run\)\<br /\>- *retry*\_*manual* \(manual retry\)\<br /\>- *retry*\_*sched* \(scheduled retry\)\<br /\>- *sub*\_*process* \(subprocess call\)\<br /\>- *test*\_*manual* \(test mode run\)
        :type execution_type: ExecutionType
        :param inbound_document_count: The number of processed inbound documents., defaults to None
        :type inbound_document_count: int, optional
        :param inbound_document_size: The aggregate size in bytes of the processed inbound documents., defaults to None
        :type inbound_document_size: int, optional
        :param inbound_error_document_count: The number of processed inbound documents with errors., defaults to None
        :type inbound_error_document_count: int, optional
        :param launcher_id: The API Service component that kicks off the run.\<br /\>\<br /\> **Note:** The Runtime must have the **API Type** set to **Advanced** on the **Shared Web Server** tab of **Runtime Management** to specify the launcherID.
        :type launcher_id: str
        :param message: Any error message returned from the run.
        :type message: str
        :param node_id: The ID of the Molecule node in which the run occurred for a process run in a Runtime cluster or Runtime cloud. For a run occurring in a Runtime, this field is omitted.
        :type node_id: str
        :param original_execution_id: The original execution ID, if this execution is a retry.
        :type original_execution_id: str
        :param outbound_document_count: The number of processed outbound documents., defaults to None
        :type outbound_document_count: int, optional
        :param outbound_document_size: The aggregate size in bytes of the processed outbound documents., defaults to None
        :type outbound_document_size: int, optional
        :param parent_execution_id: The ID of the run of the parent process, if this run and the parent process’ run were both subprocesses.
        :type parent_execution_id: str
        :param process_id: The ID of the run process.
        :type process_id: str
        :param process_name: The name of the run process.
        :type process_name: str
        :param recorded_date: The end time when the process execution completes.
        :type recorded_date: str
        :param report_key: The web service user that authenticated to make the run request.\<br /\>\<br /\>**Note:** For Runtimes with an Authentication Type of External Provider, the reportKey is the API Key. Otherwise, it is the specified user name.
        :type report_key: str
        :param status: The status of the run. Possible values are:\<br /\>- *ABORTED*\<br /\>- *COMPLETE*\<br /\>- *COMPLETE*\_*WARN*\<br /\>- *DISCARDED*\<br /\>- *ERROR*\<br /\>- *INPROCESS*\<br /\>- *STARTED*
        :type status: str
        :param top_level_execution_id: The ID of the run of the top-level process, if this run is a subprocess.
        :type top_level_execution_id: str
        """
        self.account = account
        self.atom_id = atom_id
        self.atom_name = atom_name
        if execution_duration is not SENTINEL:
            self.execution_duration = execution_duration
        self.execution_id = execution_id
        self.execution_time = execution_time
        self.execution_type = self._enum_matching(
            execution_type, ExecutionType.list(), "execution_type"
        )
        if inbound_document_count is not SENTINEL:
            self.inbound_document_count = inbound_document_count
        if inbound_document_size is not SENTINEL:
            self.inbound_document_size = inbound_document_size
        if inbound_error_document_count is not SENTINEL:
            self.inbound_error_document_count = inbound_error_document_count
        if launcher_id is not SENTINEL:
            self.launcher_id = launcher_id
        if message is not SENTINEL:
            self.message = message
        if node_id is not SENTINEL:
            self.node_id = node_id
        if original_execution_id is not SENTINEL:
            self.original_execution_id = original_execution_id
        if outbound_document_count is not SENTINEL:
            self.outbound_document_count = outbound_document_count
        if outbound_document_size is not SENTINEL:
            self.outbound_document_size = outbound_document_size
        if parent_execution_id is not SENTINEL:
            self.parent_execution_id = parent_execution_id
        self.process_id = process_id
        self.process_name = process_name
        self.recorded_date = recorded_date
        if report_key is not SENTINEL:
            self.report_key = report_key
        self.status = status
        if top_level_execution_id is not SENTINEL:
            self.top_level_execution_id = top_level_execution_id
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .document_count_account_group_expression import (
    DocumentCountAccountGroupExpression,
    DocumentCountAccountGroupExpressionGuard,
)
from .document_count_account_group_simple_expression import (
    DocumentCountAccountGroupSimpleExpression,
)
from .document_count_account_group_grouping_expression import (
    DocumentCountAccountGroupGroupingExpression,
)


@JsonMap({})
class DocumentCountAccountGroupQueryConfigQueryFilter(BaseModel):
    """DocumentCountAccountGroupQueryConfigQueryFilter

    :param expression: expression
    :type expression: DocumentCountAccountGroupExpression
    """

    def __init__(self, expression: DocumentCountAccountGroupExpression, **kwargs):
        """DocumentCountAccountGroupQueryConfigQueryFilter

        :param expression: expression
        :type expression: DocumentCountAccountGroupExpression
        """
        self.expression = DocumentCountAccountGroupExpressionGuard.return_one_of(
            expression
        )
        self._kwargs = kwargs


@JsonMap({"query_filter": "QueryFilter"})
class DocumentCountAccountGroupQueryConfig(BaseModel):
    """DocumentCountAccountGroupQueryConfig

    :param query_filter: query_filter
    :type query_filter: DocumentCountAccountGroupQueryConfigQueryFilter
    """

    def __init__(
        self, query_filter: DocumentCountAccountGroupQueryConfigQueryFilter, **kwargs
    ):
        """DocumentCountAccountGroupQueryConfig

        :param query_filter: query_filter
        :type query_filter: DocumentCountAccountGroupQueryConfigQueryFilter
        """
        self.query_filter = self._define_object(
            query_filter, DocumentCountAccountGroupQueryConfigQueryFilter
        )
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..rerun_document import RerunDocumentService
from ...models import RerunDocument


class RerunDocumentServiceAsync(RerunDocumentService):
    """
    Async Wrapper for RerunDocumentServiceAsync
    """

    def create_rerun_document(
        self, request_body: RerunDocument = None
    ) -> Awaitable[Union[RerunDocument, str]]:
        return to_async(super().create_rerun_document)(request_body)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .map_extensions_extended_node import MapExtensionsExtendedNode


@JsonMap({"node": "Node"})
class MapExtensionExtendProfile(BaseModel):
    """Contains the user-defined custom fields for the source or destination profile. Applicable only to Flat File profiles. Represents the field and value configuration settings manually specified in the source or destination profile's Data Element tab. For more information, refer to [Customizing Profiles](/docs/APIs/PlatformAPI/Customizing_profiles_environment_map_extension).

    :param node: node, defaults to None
    :type node: List[MapExtensionsExtendedNode], optional
    """

    def __init__(self, node: List[MapExtensionsExtendedNode] = SENTINEL, **kwargs):
        """Contains the user-defined custom fields for the source or destination profile. Applicable only to Flat File profiles. Represents the field and value configuration settings manually specified in the source or destination profile's Data Element tab. For more information, refer to [Customizing Profiles](/docs/APIs/PlatformAPI/Customizing_profiles_environment_map_extension).

        :param node: node, defaults to None
        :type node: List[MapExtensionsExtendedNode], optional
        """
        if node is not SENTINEL:
            self.node = self._define_list(node, MapExtensionsExtendedNode)
        self._kwargs = kwargs
